// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package gluedatabrew

import (
	"fmt"
	"time"

	"github.com/aws/aws-sdk-go/aws"
	"github.com/aws/aws-sdk-go/aws/awsutil"
	"github.com/aws/aws-sdk-go/aws/request"
	"github.com/aws/aws-sdk-go/private/protocol"
	"github.com/aws/aws-sdk-go/private/protocol/restjson"
)

const opBatchDeleteRecipeVersion = "BatchDeleteRecipeVersion"

// BatchDeleteRecipeVersionRequest generates a "aws/request.Request" representing the
// client's request for the BatchDeleteRecipeVersion operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See BatchDeleteRecipeVersion for more information on using the BatchDeleteRecipeVersion
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the BatchDeleteRecipeVersionRequest method.
//    req, resp := client.BatchDeleteRecipeVersionRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/BatchDeleteRecipeVersion
func (c *GlueDataBrew) BatchDeleteRecipeVersionRequest(input *BatchDeleteRecipeVersionInput) (req *request.Request, output *BatchDeleteRecipeVersionOutput) {
	op := &request.Operation{
		Name:       opBatchDeleteRecipeVersion,
		HTTPMethod: "POST",
		HTTPPath:   "/recipes/{name}/batchDeleteRecipeVersion",
	}

	if input == nil {
		input = &BatchDeleteRecipeVersionInput{}
	}

	output = &BatchDeleteRecipeVersionOutput{}
	req = c.newRequest(op, input, output)
	return
}

// BatchDeleteRecipeVersion API operation for AWS Glue DataBrew.
//
// Deletes one or more versions of a recipe at a time.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation BatchDeleteRecipeVersion for usage and error information.
//
// Returned Error Types:
//   * ConflictException
//   Updating or deleting a resource can cause an inconsistent state.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/BatchDeleteRecipeVersion
func (c *GlueDataBrew) BatchDeleteRecipeVersion(input *BatchDeleteRecipeVersionInput) (*BatchDeleteRecipeVersionOutput, error) {
	req, out := c.BatchDeleteRecipeVersionRequest(input)
	return out, req.Send()
}

// BatchDeleteRecipeVersionWithContext is the same as BatchDeleteRecipeVersion with the addition of
// the ability to pass a context and additional request options.
//
// See BatchDeleteRecipeVersion for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) BatchDeleteRecipeVersionWithContext(ctx aws.Context, input *BatchDeleteRecipeVersionInput, opts ...request.Option) (*BatchDeleteRecipeVersionOutput, error) {
	req, out := c.BatchDeleteRecipeVersionRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opCreateDataset = "CreateDataset"

// CreateDatasetRequest generates a "aws/request.Request" representing the
// client's request for the CreateDataset operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See CreateDataset for more information on using the CreateDataset
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the CreateDatasetRequest method.
//    req, resp := client.CreateDatasetRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateDataset
func (c *GlueDataBrew) CreateDatasetRequest(input *CreateDatasetInput) (req *request.Request, output *CreateDatasetOutput) {
	op := &request.Operation{
		Name:       opCreateDataset,
		HTTPMethod: "POST",
		HTTPPath:   "/datasets",
	}

	if input == nil {
		input = &CreateDatasetInput{}
	}

	output = &CreateDatasetOutput{}
	req = c.newRequest(op, input, output)
	return
}

// CreateDataset API operation for AWS Glue DataBrew.
//
// Creates a new AWS Glue DataBrew dataset for this AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation CreateDataset for usage and error information.
//
// Returned Error Types:
//   * AccessDeniedException
//   Access to the specified resource was denied.
//
//   * ConflictException
//   Updating or deleting a resource can cause an inconsistent state.
//
//   * ServiceQuotaExceededException
//   A service quota is exceeded.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateDataset
func (c *GlueDataBrew) CreateDataset(input *CreateDatasetInput) (*CreateDatasetOutput, error) {
	req, out := c.CreateDatasetRequest(input)
	return out, req.Send()
}

// CreateDatasetWithContext is the same as CreateDataset with the addition of
// the ability to pass a context and additional request options.
//
// See CreateDataset for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) CreateDatasetWithContext(ctx aws.Context, input *CreateDatasetInput, opts ...request.Option) (*CreateDatasetOutput, error) {
	req, out := c.CreateDatasetRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opCreateProfileJob = "CreateProfileJob"

// CreateProfileJobRequest generates a "aws/request.Request" representing the
// client's request for the CreateProfileJob operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See CreateProfileJob for more information on using the CreateProfileJob
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the CreateProfileJobRequest method.
//    req, resp := client.CreateProfileJobRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateProfileJob
func (c *GlueDataBrew) CreateProfileJobRequest(input *CreateProfileJobInput) (req *request.Request, output *CreateProfileJobOutput) {
	op := &request.Operation{
		Name:       opCreateProfileJob,
		HTTPMethod: "POST",
		HTTPPath:   "/profileJobs",
	}

	if input == nil {
		input = &CreateProfileJobInput{}
	}

	output = &CreateProfileJobOutput{}
	req = c.newRequest(op, input, output)
	return
}

// CreateProfileJob API operation for AWS Glue DataBrew.
//
// Creates a new job to profile an AWS Glue DataBrew dataset that exists in
// the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation CreateProfileJob for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateProfileJob
func (c *GlueDataBrew) CreateProfileJob(input *CreateProfileJobInput) (*CreateProfileJobOutput, error) {
	req, out := c.CreateProfileJobRequest(input)
	return out, req.Send()
}

// CreateProfileJobWithContext is the same as CreateProfileJob with the addition of
// the ability to pass a context and additional request options.
//
// See CreateProfileJob for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) CreateProfileJobWithContext(ctx aws.Context, input *CreateProfileJobInput, opts ...request.Option) (*CreateProfileJobOutput, error) {
	req, out := c.CreateProfileJobRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opCreateProject = "CreateProject"

// CreateProjectRequest generates a "aws/request.Request" representing the
// client's request for the CreateProject operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See CreateProject for more information on using the CreateProject
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the CreateProjectRequest method.
//    req, resp := client.CreateProjectRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateProject
func (c *GlueDataBrew) CreateProjectRequest(input *CreateProjectInput) (req *request.Request, output *CreateProjectOutput) {
	op := &request.Operation{
		Name:       opCreateProject,
		HTTPMethod: "POST",
		HTTPPath:   "/projects",
	}

	if input == nil {
		input = &CreateProjectInput{}
	}

	output = &CreateProjectOutput{}
	req = c.newRequest(op, input, output)
	return
}

// CreateProject API operation for AWS Glue DataBrew.
//
// Creates a new AWS Glue DataBrew project in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation CreateProject for usage and error information.
//
// Returned Error Types:
//   * ConflictException
//   Updating or deleting a resource can cause an inconsistent state.
//
//   * InternalServerException
//   An internal service failure occurred.
//
//   * ServiceQuotaExceededException
//   A service quota is exceeded.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateProject
func (c *GlueDataBrew) CreateProject(input *CreateProjectInput) (*CreateProjectOutput, error) {
	req, out := c.CreateProjectRequest(input)
	return out, req.Send()
}

// CreateProjectWithContext is the same as CreateProject with the addition of
// the ability to pass a context and additional request options.
//
// See CreateProject for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) CreateProjectWithContext(ctx aws.Context, input *CreateProjectInput, opts ...request.Option) (*CreateProjectOutput, error) {
	req, out := c.CreateProjectRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opCreateRecipe = "CreateRecipe"

// CreateRecipeRequest generates a "aws/request.Request" representing the
// client's request for the CreateRecipe operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See CreateRecipe for more information on using the CreateRecipe
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the CreateRecipeRequest method.
//    req, resp := client.CreateRecipeRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipe
func (c *GlueDataBrew) CreateRecipeRequest(input *CreateRecipeInput) (req *request.Request, output *CreateRecipeOutput) {
	op := &request.Operation{
		Name:       opCreateRecipe,
		HTTPMethod: "POST",
		HTTPPath:   "/recipes",
	}

	if input == nil {
		input = &CreateRecipeInput{}
	}

	output = &CreateRecipeOutput{}
	req = c.newRequest(op, input, output)
	return
}

// CreateRecipe API operation for AWS Glue DataBrew.
//
// Creates a new AWS Glue DataBrew recipe for the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation CreateRecipe for usage and error information.
//
// Returned Error Types:
//   * ConflictException
//   Updating or deleting a resource can cause an inconsistent state.
//
//   * ServiceQuotaExceededException
//   A service quota is exceeded.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipe
func (c *GlueDataBrew) CreateRecipe(input *CreateRecipeInput) (*CreateRecipeOutput, error) {
	req, out := c.CreateRecipeRequest(input)
	return out, req.Send()
}

// CreateRecipeWithContext is the same as CreateRecipe with the addition of
// the ability to pass a context and additional request options.
//
// See CreateRecipe for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) CreateRecipeWithContext(ctx aws.Context, input *CreateRecipeInput, opts ...request.Option) (*CreateRecipeOutput, error) {
	req, out := c.CreateRecipeRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opCreateRecipeJob = "CreateRecipeJob"

// CreateRecipeJobRequest generates a "aws/request.Request" representing the
// client's request for the CreateRecipeJob operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See CreateRecipeJob for more information on using the CreateRecipeJob
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the CreateRecipeJobRequest method.
//    req, resp := client.CreateRecipeJobRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob
func (c *GlueDataBrew) CreateRecipeJobRequest(input *CreateRecipeJobInput) (req *request.Request, output *CreateRecipeJobOutput) {
	op := &request.Operation{
		Name:       opCreateRecipeJob,
		HTTPMethod: "POST",
		HTTPPath:   "/recipeJobs",
	}

	if input == nil {
		input = &CreateRecipeJobInput{}
	}

	output = &CreateRecipeJobOutput{}
	req = c.newRequest(op, input, output)
	return
}

// CreateRecipeJob API operation for AWS Glue DataBrew.
//
// Creates a new job for an existing AWS Glue DataBrew recipe in the current
// AWS account. You can create a standalone job using either a project, or a
// combination of a recipe and a dataset.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation CreateRecipeJob for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob
func (c *GlueDataBrew) CreateRecipeJob(input *CreateRecipeJobInput) (*CreateRecipeJobOutput, error) {
	req, out := c.CreateRecipeJobRequest(input)
	return out, req.Send()
}

// CreateRecipeJobWithContext is the same as CreateRecipeJob with the addition of
// the ability to pass a context and additional request options.
//
// See CreateRecipeJob for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) CreateRecipeJobWithContext(ctx aws.Context, input *CreateRecipeJobInput, opts ...request.Option) (*CreateRecipeJobOutput, error) {
	req, out := c.CreateRecipeJobRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opCreateSchedule = "CreateSchedule"

// CreateScheduleRequest generates a "aws/request.Request" representing the
// client's request for the CreateSchedule operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See CreateSchedule for more information on using the CreateSchedule
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the CreateScheduleRequest method.
//    req, resp := client.CreateScheduleRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateSchedule
func (c *GlueDataBrew) CreateScheduleRequest(input *CreateScheduleInput) (req *request.Request, output *CreateScheduleOutput) {
	op := &request.Operation{
		Name:       opCreateSchedule,
		HTTPMethod: "POST",
		HTTPPath:   "/schedules",
	}

	if input == nil {
		input = &CreateScheduleInput{}
	}

	output = &CreateScheduleOutput{}
	req = c.newRequest(op, input, output)
	return
}

// CreateSchedule API operation for AWS Glue DataBrew.
//
// Creates a new schedule for one or more AWS Glue DataBrew jobs. Jobs can be
// run at a specific date and time, or at regular intervals.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation CreateSchedule for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateSchedule
func (c *GlueDataBrew) CreateSchedule(input *CreateScheduleInput) (*CreateScheduleOutput, error) {
	req, out := c.CreateScheduleRequest(input)
	return out, req.Send()
}

// CreateScheduleWithContext is the same as CreateSchedule with the addition of
// the ability to pass a context and additional request options.
//
// See CreateSchedule for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) CreateScheduleWithContext(ctx aws.Context, input *CreateScheduleInput, opts ...request.Option) (*CreateScheduleOutput, error) {
	req, out := c.CreateScheduleRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDeleteDataset = "DeleteDataset"

// DeleteDatasetRequest generates a "aws/request.Request" representing the
// client's request for the DeleteDataset operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DeleteDataset for more information on using the DeleteDataset
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DeleteDatasetRequest method.
//    req, resp := client.DeleteDatasetRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteDataset
func (c *GlueDataBrew) DeleteDatasetRequest(input *DeleteDatasetInput) (req *request.Request, output *DeleteDatasetOutput) {
	op := &request.Operation{
		Name:       opDeleteDataset,
		HTTPMethod: "DELETE",
		HTTPPath:   "/datasets/{name}",
	}

	if input == nil {
		input = &DeleteDatasetInput{}
	}

	output = &DeleteDatasetOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DeleteDataset API operation for AWS Glue DataBrew.
//
// Deletes a dataset from AWS Glue DataBrew.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DeleteDataset for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteDataset
func (c *GlueDataBrew) DeleteDataset(input *DeleteDatasetInput) (*DeleteDatasetOutput, error) {
	req, out := c.DeleteDatasetRequest(input)
	return out, req.Send()
}

// DeleteDatasetWithContext is the same as DeleteDataset with the addition of
// the ability to pass a context and additional request options.
//
// See DeleteDataset for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DeleteDatasetWithContext(ctx aws.Context, input *DeleteDatasetInput, opts ...request.Option) (*DeleteDatasetOutput, error) {
	req, out := c.DeleteDatasetRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDeleteJob = "DeleteJob"

// DeleteJobRequest generates a "aws/request.Request" representing the
// client's request for the DeleteJob operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DeleteJob for more information on using the DeleteJob
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DeleteJobRequest method.
//    req, resp := client.DeleteJobRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteJob
func (c *GlueDataBrew) DeleteJobRequest(input *DeleteJobInput) (req *request.Request, output *DeleteJobOutput) {
	op := &request.Operation{
		Name:       opDeleteJob,
		HTTPMethod: "DELETE",
		HTTPPath:   "/jobs/{name}",
	}

	if input == nil {
		input = &DeleteJobInput{}
	}

	output = &DeleteJobOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DeleteJob API operation for AWS Glue DataBrew.
//
// Deletes the specified AWS Glue DataBrew job from the current AWS account.
// The job can be for a recipe or for a profile.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DeleteJob for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteJob
func (c *GlueDataBrew) DeleteJob(input *DeleteJobInput) (*DeleteJobOutput, error) {
	req, out := c.DeleteJobRequest(input)
	return out, req.Send()
}

// DeleteJobWithContext is the same as DeleteJob with the addition of
// the ability to pass a context and additional request options.
//
// See DeleteJob for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DeleteJobWithContext(ctx aws.Context, input *DeleteJobInput, opts ...request.Option) (*DeleteJobOutput, error) {
	req, out := c.DeleteJobRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDeleteProject = "DeleteProject"

// DeleteProjectRequest generates a "aws/request.Request" representing the
// client's request for the DeleteProject operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DeleteProject for more information on using the DeleteProject
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DeleteProjectRequest method.
//    req, resp := client.DeleteProjectRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteProject
func (c *GlueDataBrew) DeleteProjectRequest(input *DeleteProjectInput) (req *request.Request, output *DeleteProjectOutput) {
	op := &request.Operation{
		Name:       opDeleteProject,
		HTTPMethod: "DELETE",
		HTTPPath:   "/projects/{name}",
	}

	if input == nil {
		input = &DeleteProjectInput{}
	}

	output = &DeleteProjectOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DeleteProject API operation for AWS Glue DataBrew.
//
// Deletes an existing AWS Glue DataBrew project from the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DeleteProject for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteProject
func (c *GlueDataBrew) DeleteProject(input *DeleteProjectInput) (*DeleteProjectOutput, error) {
	req, out := c.DeleteProjectRequest(input)
	return out, req.Send()
}

// DeleteProjectWithContext is the same as DeleteProject with the addition of
// the ability to pass a context and additional request options.
//
// See DeleteProject for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DeleteProjectWithContext(ctx aws.Context, input *DeleteProjectInput, opts ...request.Option) (*DeleteProjectOutput, error) {
	req, out := c.DeleteProjectRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDeleteRecipeVersion = "DeleteRecipeVersion"

// DeleteRecipeVersionRequest generates a "aws/request.Request" representing the
// client's request for the DeleteRecipeVersion operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DeleteRecipeVersion for more information on using the DeleteRecipeVersion
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DeleteRecipeVersionRequest method.
//    req, resp := client.DeleteRecipeVersionRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteRecipeVersion
func (c *GlueDataBrew) DeleteRecipeVersionRequest(input *DeleteRecipeVersionInput) (req *request.Request, output *DeleteRecipeVersionOutput) {
	op := &request.Operation{
		Name:       opDeleteRecipeVersion,
		HTTPMethod: "DELETE",
		HTTPPath:   "/recipes/{name}/recipeVersion/{recipeVersion}",
	}

	if input == nil {
		input = &DeleteRecipeVersionInput{}
	}

	output = &DeleteRecipeVersionOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DeleteRecipeVersion API operation for AWS Glue DataBrew.
//
// Deletes a single version of an AWS Glue DataBrew recipe.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DeleteRecipeVersion for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteRecipeVersion
func (c *GlueDataBrew) DeleteRecipeVersion(input *DeleteRecipeVersionInput) (*DeleteRecipeVersionOutput, error) {
	req, out := c.DeleteRecipeVersionRequest(input)
	return out, req.Send()
}

// DeleteRecipeVersionWithContext is the same as DeleteRecipeVersion with the addition of
// the ability to pass a context and additional request options.
//
// See DeleteRecipeVersion for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DeleteRecipeVersionWithContext(ctx aws.Context, input *DeleteRecipeVersionInput, opts ...request.Option) (*DeleteRecipeVersionOutput, error) {
	req, out := c.DeleteRecipeVersionRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDeleteSchedule = "DeleteSchedule"

// DeleteScheduleRequest generates a "aws/request.Request" representing the
// client's request for the DeleteSchedule operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DeleteSchedule for more information on using the DeleteSchedule
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DeleteScheduleRequest method.
//    req, resp := client.DeleteScheduleRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteSchedule
func (c *GlueDataBrew) DeleteScheduleRequest(input *DeleteScheduleInput) (req *request.Request, output *DeleteScheduleOutput) {
	op := &request.Operation{
		Name:       opDeleteSchedule,
		HTTPMethod: "DELETE",
		HTTPPath:   "/schedules/{name}",
	}

	if input == nil {
		input = &DeleteScheduleInput{}
	}

	output = &DeleteScheduleOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DeleteSchedule API operation for AWS Glue DataBrew.
//
// Deletes the specified AWS Glue DataBrew schedule from the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DeleteSchedule for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DeleteSchedule
func (c *GlueDataBrew) DeleteSchedule(input *DeleteScheduleInput) (*DeleteScheduleOutput, error) {
	req, out := c.DeleteScheduleRequest(input)
	return out, req.Send()
}

// DeleteScheduleWithContext is the same as DeleteSchedule with the addition of
// the ability to pass a context and additional request options.
//
// See DeleteSchedule for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DeleteScheduleWithContext(ctx aws.Context, input *DeleteScheduleInput, opts ...request.Option) (*DeleteScheduleOutput, error) {
	req, out := c.DeleteScheduleRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDescribeDataset = "DescribeDataset"

// DescribeDatasetRequest generates a "aws/request.Request" representing the
// client's request for the DescribeDataset operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DescribeDataset for more information on using the DescribeDataset
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DescribeDatasetRequest method.
//    req, resp := client.DescribeDatasetRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeDataset
func (c *GlueDataBrew) DescribeDatasetRequest(input *DescribeDatasetInput) (req *request.Request, output *DescribeDatasetOutput) {
	op := &request.Operation{
		Name:       opDescribeDataset,
		HTTPMethod: "GET",
		HTTPPath:   "/datasets/{name}",
	}

	if input == nil {
		input = &DescribeDatasetInput{}
	}

	output = &DescribeDatasetOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DescribeDataset API operation for AWS Glue DataBrew.
//
// Returns the definition of a specific AWS Glue DataBrew dataset that is in
// the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DescribeDataset for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeDataset
func (c *GlueDataBrew) DescribeDataset(input *DescribeDatasetInput) (*DescribeDatasetOutput, error) {
	req, out := c.DescribeDatasetRequest(input)
	return out, req.Send()
}

// DescribeDatasetWithContext is the same as DescribeDataset with the addition of
// the ability to pass a context and additional request options.
//
// See DescribeDataset for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DescribeDatasetWithContext(ctx aws.Context, input *DescribeDatasetInput, opts ...request.Option) (*DescribeDatasetOutput, error) {
	req, out := c.DescribeDatasetRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDescribeJob = "DescribeJob"

// DescribeJobRequest generates a "aws/request.Request" representing the
// client's request for the DescribeJob operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DescribeJob for more information on using the DescribeJob
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DescribeJobRequest method.
//    req, resp := client.DescribeJobRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeJob
func (c *GlueDataBrew) DescribeJobRequest(input *DescribeJobInput) (req *request.Request, output *DescribeJobOutput) {
	op := &request.Operation{
		Name:       opDescribeJob,
		HTTPMethod: "GET",
		HTTPPath:   "/jobs/{name}",
	}

	if input == nil {
		input = &DescribeJobInput{}
	}

	output = &DescribeJobOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DescribeJob API operation for AWS Glue DataBrew.
//
// Returns the definition of a specific AWS Glue DataBrew job that is in the
// current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DescribeJob for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeJob
func (c *GlueDataBrew) DescribeJob(input *DescribeJobInput) (*DescribeJobOutput, error) {
	req, out := c.DescribeJobRequest(input)
	return out, req.Send()
}

// DescribeJobWithContext is the same as DescribeJob with the addition of
// the ability to pass a context and additional request options.
//
// See DescribeJob for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DescribeJobWithContext(ctx aws.Context, input *DescribeJobInput, opts ...request.Option) (*DescribeJobOutput, error) {
	req, out := c.DescribeJobRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDescribeProject = "DescribeProject"

// DescribeProjectRequest generates a "aws/request.Request" representing the
// client's request for the DescribeProject operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DescribeProject for more information on using the DescribeProject
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DescribeProjectRequest method.
//    req, resp := client.DescribeProjectRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeProject
func (c *GlueDataBrew) DescribeProjectRequest(input *DescribeProjectInput) (req *request.Request, output *DescribeProjectOutput) {
	op := &request.Operation{
		Name:       opDescribeProject,
		HTTPMethod: "GET",
		HTTPPath:   "/projects/{name}",
	}

	if input == nil {
		input = &DescribeProjectInput{}
	}

	output = &DescribeProjectOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DescribeProject API operation for AWS Glue DataBrew.
//
// Returns the definition of a specific AWS Glue DataBrew project that is in
// the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DescribeProject for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeProject
func (c *GlueDataBrew) DescribeProject(input *DescribeProjectInput) (*DescribeProjectOutput, error) {
	req, out := c.DescribeProjectRequest(input)
	return out, req.Send()
}

// DescribeProjectWithContext is the same as DescribeProject with the addition of
// the ability to pass a context and additional request options.
//
// See DescribeProject for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DescribeProjectWithContext(ctx aws.Context, input *DescribeProjectInput, opts ...request.Option) (*DescribeProjectOutput, error) {
	req, out := c.DescribeProjectRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDescribeRecipe = "DescribeRecipe"

// DescribeRecipeRequest generates a "aws/request.Request" representing the
// client's request for the DescribeRecipe operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DescribeRecipe for more information on using the DescribeRecipe
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DescribeRecipeRequest method.
//    req, resp := client.DescribeRecipeRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeRecipe
func (c *GlueDataBrew) DescribeRecipeRequest(input *DescribeRecipeInput) (req *request.Request, output *DescribeRecipeOutput) {
	op := &request.Operation{
		Name:       opDescribeRecipe,
		HTTPMethod: "GET",
		HTTPPath:   "/recipes/{name}",
	}

	if input == nil {
		input = &DescribeRecipeInput{}
	}

	output = &DescribeRecipeOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DescribeRecipe API operation for AWS Glue DataBrew.
//
// Returns the definition of a specific AWS Glue DataBrew recipe that is in
// the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DescribeRecipe for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeRecipe
func (c *GlueDataBrew) DescribeRecipe(input *DescribeRecipeInput) (*DescribeRecipeOutput, error) {
	req, out := c.DescribeRecipeRequest(input)
	return out, req.Send()
}

// DescribeRecipeWithContext is the same as DescribeRecipe with the addition of
// the ability to pass a context and additional request options.
//
// See DescribeRecipe for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DescribeRecipeWithContext(ctx aws.Context, input *DescribeRecipeInput, opts ...request.Option) (*DescribeRecipeOutput, error) {
	req, out := c.DescribeRecipeRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opDescribeSchedule = "DescribeSchedule"

// DescribeScheduleRequest generates a "aws/request.Request" representing the
// client's request for the DescribeSchedule operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See DescribeSchedule for more information on using the DescribeSchedule
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the DescribeScheduleRequest method.
//    req, resp := client.DescribeScheduleRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeSchedule
func (c *GlueDataBrew) DescribeScheduleRequest(input *DescribeScheduleInput) (req *request.Request, output *DescribeScheduleOutput) {
	op := &request.Operation{
		Name:       opDescribeSchedule,
		HTTPMethod: "GET",
		HTTPPath:   "/schedules/{name}",
	}

	if input == nil {
		input = &DescribeScheduleInput{}
	}

	output = &DescribeScheduleOutput{}
	req = c.newRequest(op, input, output)
	return
}

// DescribeSchedule API operation for AWS Glue DataBrew.
//
// Returns the definition of a specific AWS Glue DataBrew schedule that is in
// the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation DescribeSchedule for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/DescribeSchedule
func (c *GlueDataBrew) DescribeSchedule(input *DescribeScheduleInput) (*DescribeScheduleOutput, error) {
	req, out := c.DescribeScheduleRequest(input)
	return out, req.Send()
}

// DescribeScheduleWithContext is the same as DescribeSchedule with the addition of
// the ability to pass a context and additional request options.
//
// See DescribeSchedule for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) DescribeScheduleWithContext(ctx aws.Context, input *DescribeScheduleInput, opts ...request.Option) (*DescribeScheduleOutput, error) {
	req, out := c.DescribeScheduleRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opListDatasets = "ListDatasets"

// ListDatasetsRequest generates a "aws/request.Request" representing the
// client's request for the ListDatasets operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListDatasets for more information on using the ListDatasets
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListDatasetsRequest method.
//    req, resp := client.ListDatasetsRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListDatasets
func (c *GlueDataBrew) ListDatasetsRequest(input *ListDatasetsInput) (req *request.Request, output *ListDatasetsOutput) {
	op := &request.Operation{
		Name:       opListDatasets,
		HTTPMethod: "GET",
		HTTPPath:   "/datasets",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListDatasetsInput{}
	}

	output = &ListDatasetsOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListDatasets API operation for AWS Glue DataBrew.
//
// Lists all of the AWS Glue DataBrew datasets for the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListDatasets for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListDatasets
func (c *GlueDataBrew) ListDatasets(input *ListDatasetsInput) (*ListDatasetsOutput, error) {
	req, out := c.ListDatasetsRequest(input)
	return out, req.Send()
}

// ListDatasetsWithContext is the same as ListDatasets with the addition of
// the ability to pass a context and additional request options.
//
// See ListDatasets for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListDatasetsWithContext(ctx aws.Context, input *ListDatasetsInput, opts ...request.Option) (*ListDatasetsOutput, error) {
	req, out := c.ListDatasetsRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListDatasetsPages iterates over the pages of a ListDatasets operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListDatasets method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListDatasets operation.
//    pageNum := 0
//    err := client.ListDatasetsPages(params,
//        func(page *gluedatabrew.ListDatasetsOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListDatasetsPages(input *ListDatasetsInput, fn func(*ListDatasetsOutput, bool) bool) error {
	return c.ListDatasetsPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListDatasetsPagesWithContext same as ListDatasetsPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListDatasetsPagesWithContext(ctx aws.Context, input *ListDatasetsInput, fn func(*ListDatasetsOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListDatasetsInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListDatasetsRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListDatasetsOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListJobRuns = "ListJobRuns"

// ListJobRunsRequest generates a "aws/request.Request" representing the
// client's request for the ListJobRuns operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListJobRuns for more information on using the ListJobRuns
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListJobRunsRequest method.
//    req, resp := client.ListJobRunsRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListJobRuns
func (c *GlueDataBrew) ListJobRunsRequest(input *ListJobRunsInput) (req *request.Request, output *ListJobRunsOutput) {
	op := &request.Operation{
		Name:       opListJobRuns,
		HTTPMethod: "GET",
		HTTPPath:   "/jobs/{name}/jobRuns",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListJobRunsInput{}
	}

	output = &ListJobRunsOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListJobRuns API operation for AWS Glue DataBrew.
//
// Lists all of the previous runs of a particular AWS Glue DataBrew job in the
// current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListJobRuns for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListJobRuns
func (c *GlueDataBrew) ListJobRuns(input *ListJobRunsInput) (*ListJobRunsOutput, error) {
	req, out := c.ListJobRunsRequest(input)
	return out, req.Send()
}

// ListJobRunsWithContext is the same as ListJobRuns with the addition of
// the ability to pass a context and additional request options.
//
// See ListJobRuns for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListJobRunsWithContext(ctx aws.Context, input *ListJobRunsInput, opts ...request.Option) (*ListJobRunsOutput, error) {
	req, out := c.ListJobRunsRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListJobRunsPages iterates over the pages of a ListJobRuns operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListJobRuns method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListJobRuns operation.
//    pageNum := 0
//    err := client.ListJobRunsPages(params,
//        func(page *gluedatabrew.ListJobRunsOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListJobRunsPages(input *ListJobRunsInput, fn func(*ListJobRunsOutput, bool) bool) error {
	return c.ListJobRunsPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListJobRunsPagesWithContext same as ListJobRunsPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListJobRunsPagesWithContext(ctx aws.Context, input *ListJobRunsInput, fn func(*ListJobRunsOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListJobRunsInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListJobRunsRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListJobRunsOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListJobs = "ListJobs"

// ListJobsRequest generates a "aws/request.Request" representing the
// client's request for the ListJobs operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListJobs for more information on using the ListJobs
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListJobsRequest method.
//    req, resp := client.ListJobsRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListJobs
func (c *GlueDataBrew) ListJobsRequest(input *ListJobsInput) (req *request.Request, output *ListJobsOutput) {
	op := &request.Operation{
		Name:       opListJobs,
		HTTPMethod: "GET",
		HTTPPath:   "/jobs",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListJobsInput{}
	}

	output = &ListJobsOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListJobs API operation for AWS Glue DataBrew.
//
// Lists the AWS Glue DataBrew jobs in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListJobs for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListJobs
func (c *GlueDataBrew) ListJobs(input *ListJobsInput) (*ListJobsOutput, error) {
	req, out := c.ListJobsRequest(input)
	return out, req.Send()
}

// ListJobsWithContext is the same as ListJobs with the addition of
// the ability to pass a context and additional request options.
//
// See ListJobs for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListJobsWithContext(ctx aws.Context, input *ListJobsInput, opts ...request.Option) (*ListJobsOutput, error) {
	req, out := c.ListJobsRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListJobsPages iterates over the pages of a ListJobs operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListJobs method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListJobs operation.
//    pageNum := 0
//    err := client.ListJobsPages(params,
//        func(page *gluedatabrew.ListJobsOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListJobsPages(input *ListJobsInput, fn func(*ListJobsOutput, bool) bool) error {
	return c.ListJobsPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListJobsPagesWithContext same as ListJobsPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListJobsPagesWithContext(ctx aws.Context, input *ListJobsInput, fn func(*ListJobsOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListJobsInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListJobsRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListJobsOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListProjects = "ListProjects"

// ListProjectsRequest generates a "aws/request.Request" representing the
// client's request for the ListProjects operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListProjects for more information on using the ListProjects
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListProjectsRequest method.
//    req, resp := client.ListProjectsRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListProjects
func (c *GlueDataBrew) ListProjectsRequest(input *ListProjectsInput) (req *request.Request, output *ListProjectsOutput) {
	op := &request.Operation{
		Name:       opListProjects,
		HTTPMethod: "GET",
		HTTPPath:   "/projects",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListProjectsInput{}
	}

	output = &ListProjectsOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListProjects API operation for AWS Glue DataBrew.
//
// Lists all of the DataBrew projects in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListProjects for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListProjects
func (c *GlueDataBrew) ListProjects(input *ListProjectsInput) (*ListProjectsOutput, error) {
	req, out := c.ListProjectsRequest(input)
	return out, req.Send()
}

// ListProjectsWithContext is the same as ListProjects with the addition of
// the ability to pass a context and additional request options.
//
// See ListProjects for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListProjectsWithContext(ctx aws.Context, input *ListProjectsInput, opts ...request.Option) (*ListProjectsOutput, error) {
	req, out := c.ListProjectsRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListProjectsPages iterates over the pages of a ListProjects operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListProjects method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListProjects operation.
//    pageNum := 0
//    err := client.ListProjectsPages(params,
//        func(page *gluedatabrew.ListProjectsOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListProjectsPages(input *ListProjectsInput, fn func(*ListProjectsOutput, bool) bool) error {
	return c.ListProjectsPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListProjectsPagesWithContext same as ListProjectsPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListProjectsPagesWithContext(ctx aws.Context, input *ListProjectsInput, fn func(*ListProjectsOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListProjectsInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListProjectsRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListProjectsOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListRecipeVersions = "ListRecipeVersions"

// ListRecipeVersionsRequest generates a "aws/request.Request" representing the
// client's request for the ListRecipeVersions operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListRecipeVersions for more information on using the ListRecipeVersions
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListRecipeVersionsRequest method.
//    req, resp := client.ListRecipeVersionsRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListRecipeVersions
func (c *GlueDataBrew) ListRecipeVersionsRequest(input *ListRecipeVersionsInput) (req *request.Request, output *ListRecipeVersionsOutput) {
	op := &request.Operation{
		Name:       opListRecipeVersions,
		HTTPMethod: "GET",
		HTTPPath:   "/recipeVersions",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListRecipeVersionsInput{}
	}

	output = &ListRecipeVersionsOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListRecipeVersions API operation for AWS Glue DataBrew.
//
// Lists all of the versions of a particular AWS Glue DataBrew recipe in the
// current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListRecipeVersions for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListRecipeVersions
func (c *GlueDataBrew) ListRecipeVersions(input *ListRecipeVersionsInput) (*ListRecipeVersionsOutput, error) {
	req, out := c.ListRecipeVersionsRequest(input)
	return out, req.Send()
}

// ListRecipeVersionsWithContext is the same as ListRecipeVersions with the addition of
// the ability to pass a context and additional request options.
//
// See ListRecipeVersions for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListRecipeVersionsWithContext(ctx aws.Context, input *ListRecipeVersionsInput, opts ...request.Option) (*ListRecipeVersionsOutput, error) {
	req, out := c.ListRecipeVersionsRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListRecipeVersionsPages iterates over the pages of a ListRecipeVersions operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListRecipeVersions method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListRecipeVersions operation.
//    pageNum := 0
//    err := client.ListRecipeVersionsPages(params,
//        func(page *gluedatabrew.ListRecipeVersionsOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListRecipeVersionsPages(input *ListRecipeVersionsInput, fn func(*ListRecipeVersionsOutput, bool) bool) error {
	return c.ListRecipeVersionsPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListRecipeVersionsPagesWithContext same as ListRecipeVersionsPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListRecipeVersionsPagesWithContext(ctx aws.Context, input *ListRecipeVersionsInput, fn func(*ListRecipeVersionsOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListRecipeVersionsInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListRecipeVersionsRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListRecipeVersionsOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListRecipes = "ListRecipes"

// ListRecipesRequest generates a "aws/request.Request" representing the
// client's request for the ListRecipes operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListRecipes for more information on using the ListRecipes
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListRecipesRequest method.
//    req, resp := client.ListRecipesRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListRecipes
func (c *GlueDataBrew) ListRecipesRequest(input *ListRecipesInput) (req *request.Request, output *ListRecipesOutput) {
	op := &request.Operation{
		Name:       opListRecipes,
		HTTPMethod: "GET",
		HTTPPath:   "/recipes",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListRecipesInput{}
	}

	output = &ListRecipesOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListRecipes API operation for AWS Glue DataBrew.
//
// Lists all of the AWS Glue DataBrew recipes in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListRecipes for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListRecipes
func (c *GlueDataBrew) ListRecipes(input *ListRecipesInput) (*ListRecipesOutput, error) {
	req, out := c.ListRecipesRequest(input)
	return out, req.Send()
}

// ListRecipesWithContext is the same as ListRecipes with the addition of
// the ability to pass a context and additional request options.
//
// See ListRecipes for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListRecipesWithContext(ctx aws.Context, input *ListRecipesInput, opts ...request.Option) (*ListRecipesOutput, error) {
	req, out := c.ListRecipesRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListRecipesPages iterates over the pages of a ListRecipes operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListRecipes method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListRecipes operation.
//    pageNum := 0
//    err := client.ListRecipesPages(params,
//        func(page *gluedatabrew.ListRecipesOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListRecipesPages(input *ListRecipesInput, fn func(*ListRecipesOutput, bool) bool) error {
	return c.ListRecipesPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListRecipesPagesWithContext same as ListRecipesPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListRecipesPagesWithContext(ctx aws.Context, input *ListRecipesInput, fn func(*ListRecipesOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListRecipesInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListRecipesRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListRecipesOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListSchedules = "ListSchedules"

// ListSchedulesRequest generates a "aws/request.Request" representing the
// client's request for the ListSchedules operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListSchedules for more information on using the ListSchedules
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListSchedulesRequest method.
//    req, resp := client.ListSchedulesRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListSchedules
func (c *GlueDataBrew) ListSchedulesRequest(input *ListSchedulesInput) (req *request.Request, output *ListSchedulesOutput) {
	op := &request.Operation{
		Name:       opListSchedules,
		HTTPMethod: "GET",
		HTTPPath:   "/schedules",
		Paginator: &request.Paginator{
			InputTokens:     []string{"NextToken"},
			OutputTokens:    []string{"NextToken"},
			LimitToken:      "MaxResults",
			TruncationToken: "",
		},
	}

	if input == nil {
		input = &ListSchedulesInput{}
	}

	output = &ListSchedulesOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListSchedules API operation for AWS Glue DataBrew.
//
// Lists the AWS Glue DataBrew schedules in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListSchedules for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListSchedules
func (c *GlueDataBrew) ListSchedules(input *ListSchedulesInput) (*ListSchedulesOutput, error) {
	req, out := c.ListSchedulesRequest(input)
	return out, req.Send()
}

// ListSchedulesWithContext is the same as ListSchedules with the addition of
// the ability to pass a context and additional request options.
//
// See ListSchedules for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListSchedulesWithContext(ctx aws.Context, input *ListSchedulesInput, opts ...request.Option) (*ListSchedulesOutput, error) {
	req, out := c.ListSchedulesRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// ListSchedulesPages iterates over the pages of a ListSchedules operation,
// calling the "fn" function with the response data for each page. To stop
// iterating, return false from the fn function.
//
// See ListSchedules method for more information on how to use this operation.
//
// Note: This operation can generate multiple requests to a service.
//
//    // Example iterating over at most 3 pages of a ListSchedules operation.
//    pageNum := 0
//    err := client.ListSchedulesPages(params,
//        func(page *gluedatabrew.ListSchedulesOutput, lastPage bool) bool {
//            pageNum++
//            fmt.Println(page)
//            return pageNum <= 3
//        })
//
func (c *GlueDataBrew) ListSchedulesPages(input *ListSchedulesInput, fn func(*ListSchedulesOutput, bool) bool) error {
	return c.ListSchedulesPagesWithContext(aws.BackgroundContext(), input, fn)
}

// ListSchedulesPagesWithContext same as ListSchedulesPages except
// it takes a Context and allows setting request options on the pages.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListSchedulesPagesWithContext(ctx aws.Context, input *ListSchedulesInput, fn func(*ListSchedulesOutput, bool) bool, opts ...request.Option) error {
	p := request.Pagination{
		NewRequest: func() (*request.Request, error) {
			var inCpy *ListSchedulesInput
			if input != nil {
				tmp := *input
				inCpy = &tmp
			}
			req, _ := c.ListSchedulesRequest(inCpy)
			req.SetContext(ctx)
			req.ApplyOptions(opts...)
			return req, nil
		},
	}

	for p.Next() {
		if !fn(p.Page().(*ListSchedulesOutput), !p.HasNextPage()) {
			break
		}
	}

	return p.Err()
}

const opListTagsForResource = "ListTagsForResource"

// ListTagsForResourceRequest generates a "aws/request.Request" representing the
// client's request for the ListTagsForResource operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See ListTagsForResource for more information on using the ListTagsForResource
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the ListTagsForResourceRequest method.
//    req, resp := client.ListTagsForResourceRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListTagsForResource
func (c *GlueDataBrew) ListTagsForResourceRequest(input *ListTagsForResourceInput) (req *request.Request, output *ListTagsForResourceOutput) {
	op := &request.Operation{
		Name:       opListTagsForResource,
		HTTPMethod: "GET",
		HTTPPath:   "/tags/{ResourceArn}",
	}

	if input == nil {
		input = &ListTagsForResourceInput{}
	}

	output = &ListTagsForResourceOutput{}
	req = c.newRequest(op, input, output)
	return
}

// ListTagsForResource API operation for AWS Glue DataBrew.
//
// Lists all the tags for an AWS Glue DataBrew resource.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation ListTagsForResource for usage and error information.
//
// Returned Error Types:
//   * InternalServerException
//   An internal service failure occurred.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListTagsForResource
func (c *GlueDataBrew) ListTagsForResource(input *ListTagsForResourceInput) (*ListTagsForResourceOutput, error) {
	req, out := c.ListTagsForResourceRequest(input)
	return out, req.Send()
}

// ListTagsForResourceWithContext is the same as ListTagsForResource with the addition of
// the ability to pass a context and additional request options.
//
// See ListTagsForResource for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) ListTagsForResourceWithContext(ctx aws.Context, input *ListTagsForResourceInput, opts ...request.Option) (*ListTagsForResourceOutput, error) {
	req, out := c.ListTagsForResourceRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opPublishRecipe = "PublishRecipe"

// PublishRecipeRequest generates a "aws/request.Request" representing the
// client's request for the PublishRecipe operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See PublishRecipe for more information on using the PublishRecipe
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the PublishRecipeRequest method.
//    req, resp := client.PublishRecipeRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/PublishRecipe
func (c *GlueDataBrew) PublishRecipeRequest(input *PublishRecipeInput) (req *request.Request, output *PublishRecipeOutput) {
	op := &request.Operation{
		Name:       opPublishRecipe,
		HTTPMethod: "POST",
		HTTPPath:   "/recipes/{name}/publishRecipe",
	}

	if input == nil {
		input = &PublishRecipeInput{}
	}

	output = &PublishRecipeOutput{}
	req = c.newRequest(op, input, output)
	return
}

// PublishRecipe API operation for AWS Glue DataBrew.
//
// Publishes a new major version of an AWS Glue DataBrew recipe that exists
// in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation PublishRecipe for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/PublishRecipe
func (c *GlueDataBrew) PublishRecipe(input *PublishRecipeInput) (*PublishRecipeOutput, error) {
	req, out := c.PublishRecipeRequest(input)
	return out, req.Send()
}

// PublishRecipeWithContext is the same as PublishRecipe with the addition of
// the ability to pass a context and additional request options.
//
// See PublishRecipe for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) PublishRecipeWithContext(ctx aws.Context, input *PublishRecipeInput, opts ...request.Option) (*PublishRecipeOutput, error) {
	req, out := c.PublishRecipeRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opSendProjectSessionAction = "SendProjectSessionAction"

// SendProjectSessionActionRequest generates a "aws/request.Request" representing the
// client's request for the SendProjectSessionAction operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See SendProjectSessionAction for more information on using the SendProjectSessionAction
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the SendProjectSessionActionRequest method.
//    req, resp := client.SendProjectSessionActionRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/SendProjectSessionAction
func (c *GlueDataBrew) SendProjectSessionActionRequest(input *SendProjectSessionActionInput) (req *request.Request, output *SendProjectSessionActionOutput) {
	op := &request.Operation{
		Name:       opSendProjectSessionAction,
		HTTPMethod: "PUT",
		HTTPPath:   "/projects/{name}/sendProjectSessionAction",
	}

	if input == nil {
		input = &SendProjectSessionActionInput{}
	}

	output = &SendProjectSessionActionOutput{}
	req = c.newRequest(op, input, output)
	return
}

// SendProjectSessionAction API operation for AWS Glue DataBrew.
//
// Performs a recipe step within an interactive AWS Glue DataBrew session that's
// currently open.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation SendProjectSessionAction for usage and error information.
//
// Returned Error Types:
//   * ConflictException
//   Updating or deleting a resource can cause an inconsistent state.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/SendProjectSessionAction
func (c *GlueDataBrew) SendProjectSessionAction(input *SendProjectSessionActionInput) (*SendProjectSessionActionOutput, error) {
	req, out := c.SendProjectSessionActionRequest(input)
	return out, req.Send()
}

// SendProjectSessionActionWithContext is the same as SendProjectSessionAction with the addition of
// the ability to pass a context and additional request options.
//
// See SendProjectSessionAction for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) SendProjectSessionActionWithContext(ctx aws.Context, input *SendProjectSessionActionInput, opts ...request.Option) (*SendProjectSessionActionOutput, error) {
	req, out := c.SendProjectSessionActionRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opStartJobRun = "StartJobRun"

// StartJobRunRequest generates a "aws/request.Request" representing the
// client's request for the StartJobRun operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See StartJobRun for more information on using the StartJobRun
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the StartJobRunRequest method.
//    req, resp := client.StartJobRunRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/StartJobRun
func (c *GlueDataBrew) StartJobRunRequest(input *StartJobRunInput) (req *request.Request, output *StartJobRunOutput) {
	op := &request.Operation{
		Name:       opStartJobRun,
		HTTPMethod: "POST",
		HTTPPath:   "/jobs/{name}/startJobRun",
	}

	if input == nil {
		input = &StartJobRunInput{}
	}

	output = &StartJobRunOutput{}
	req = c.newRequest(op, input, output)
	return
}

// StartJobRun API operation for AWS Glue DataBrew.
//
// Runs an AWS Glue DataBrew job that exists in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation StartJobRun for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/StartJobRun
func (c *GlueDataBrew) StartJobRun(input *StartJobRunInput) (*StartJobRunOutput, error) {
	req, out := c.StartJobRunRequest(input)
	return out, req.Send()
}

// StartJobRunWithContext is the same as StartJobRun with the addition of
// the ability to pass a context and additional request options.
//
// See StartJobRun for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) StartJobRunWithContext(ctx aws.Context, input *StartJobRunInput, opts ...request.Option) (*StartJobRunOutput, error) {
	req, out := c.StartJobRunRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opStartProjectSession = "StartProjectSession"

// StartProjectSessionRequest generates a "aws/request.Request" representing the
// client's request for the StartProjectSession operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See StartProjectSession for more information on using the StartProjectSession
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the StartProjectSessionRequest method.
//    req, resp := client.StartProjectSessionRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/StartProjectSession
func (c *GlueDataBrew) StartProjectSessionRequest(input *StartProjectSessionInput) (req *request.Request, output *StartProjectSessionOutput) {
	op := &request.Operation{
		Name:       opStartProjectSession,
		HTTPMethod: "PUT",
		HTTPPath:   "/projects/{name}/startProjectSession",
	}

	if input == nil {
		input = &StartProjectSessionInput{}
	}

	output = &StartProjectSessionOutput{}
	req = c.newRequest(op, input, output)
	return
}

// StartProjectSession API operation for AWS Glue DataBrew.
//
// Creates an interactive session, enabling you to manipulate an AWS Glue DataBrew
// project.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation StartProjectSession for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/StartProjectSession
func (c *GlueDataBrew) StartProjectSession(input *StartProjectSessionInput) (*StartProjectSessionOutput, error) {
	req, out := c.StartProjectSessionRequest(input)
	return out, req.Send()
}

// StartProjectSessionWithContext is the same as StartProjectSession with the addition of
// the ability to pass a context and additional request options.
//
// See StartProjectSession for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) StartProjectSessionWithContext(ctx aws.Context, input *StartProjectSessionInput, opts ...request.Option) (*StartProjectSessionOutput, error) {
	req, out := c.StartProjectSessionRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opStopJobRun = "StopJobRun"

// StopJobRunRequest generates a "aws/request.Request" representing the
// client's request for the StopJobRun operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See StopJobRun for more information on using the StopJobRun
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the StopJobRunRequest method.
//    req, resp := client.StopJobRunRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/StopJobRun
func (c *GlueDataBrew) StopJobRunRequest(input *StopJobRunInput) (req *request.Request, output *StopJobRunOutput) {
	op := &request.Operation{
		Name:       opStopJobRun,
		HTTPMethod: "POST",
		HTTPPath:   "/jobs/{name}/jobRun/{runId}/stopJobRun",
	}

	if input == nil {
		input = &StopJobRunInput{}
	}

	output = &StopJobRunOutput{}
	req = c.newRequest(op, input, output)
	return
}

// StopJobRun API operation for AWS Glue DataBrew.
//
// Stops the specified job from running in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation StopJobRun for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/StopJobRun
func (c *GlueDataBrew) StopJobRun(input *StopJobRunInput) (*StopJobRunOutput, error) {
	req, out := c.StopJobRunRequest(input)
	return out, req.Send()
}

// StopJobRunWithContext is the same as StopJobRun with the addition of
// the ability to pass a context and additional request options.
//
// See StopJobRun for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) StopJobRunWithContext(ctx aws.Context, input *StopJobRunInput, opts ...request.Option) (*StopJobRunOutput, error) {
	req, out := c.StopJobRunRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opTagResource = "TagResource"

// TagResourceRequest generates a "aws/request.Request" representing the
// client's request for the TagResource operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See TagResource for more information on using the TagResource
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the TagResourceRequest method.
//    req, resp := client.TagResourceRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/TagResource
func (c *GlueDataBrew) TagResourceRequest(input *TagResourceInput) (req *request.Request, output *TagResourceOutput) {
	op := &request.Operation{
		Name:       opTagResource,
		HTTPMethod: "POST",
		HTTPPath:   "/tags/{ResourceArn}",
	}

	if input == nil {
		input = &TagResourceInput{}
	}

	output = &TagResourceOutput{}
	req = c.newRequest(op, input, output)
	req.Handlers.Unmarshal.Swap(restjson.UnmarshalHandler.Name, protocol.UnmarshalDiscardBodyHandler)
	return
}

// TagResource API operation for AWS Glue DataBrew.
//
// Adds metadata tags to an AWS Glue DataBrew resource, such as a dataset, job,
// project, or recipe.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation TagResource for usage and error information.
//
// Returned Error Types:
//   * InternalServerException
//   An internal service failure occurred.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/TagResource
func (c *GlueDataBrew) TagResource(input *TagResourceInput) (*TagResourceOutput, error) {
	req, out := c.TagResourceRequest(input)
	return out, req.Send()
}

// TagResourceWithContext is the same as TagResource with the addition of
// the ability to pass a context and additional request options.
//
// See TagResource for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) TagResourceWithContext(ctx aws.Context, input *TagResourceInput, opts ...request.Option) (*TagResourceOutput, error) {
	req, out := c.TagResourceRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUntagResource = "UntagResource"

// UntagResourceRequest generates a "aws/request.Request" representing the
// client's request for the UntagResource operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UntagResource for more information on using the UntagResource
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UntagResourceRequest method.
//    req, resp := client.UntagResourceRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UntagResource
func (c *GlueDataBrew) UntagResourceRequest(input *UntagResourceInput) (req *request.Request, output *UntagResourceOutput) {
	op := &request.Operation{
		Name:       opUntagResource,
		HTTPMethod: "DELETE",
		HTTPPath:   "/tags/{ResourceArn}",
	}

	if input == nil {
		input = &UntagResourceInput{}
	}

	output = &UntagResourceOutput{}
	req = c.newRequest(op, input, output)
	req.Handlers.Unmarshal.Swap(restjson.UnmarshalHandler.Name, protocol.UnmarshalDiscardBodyHandler)
	return
}

// UntagResource API operation for AWS Glue DataBrew.
//
// Removes metadata tags from an AWS Glue DataBrew resource.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UntagResource for usage and error information.
//
// Returned Error Types:
//   * InternalServerException
//   An internal service failure occurred.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UntagResource
func (c *GlueDataBrew) UntagResource(input *UntagResourceInput) (*UntagResourceOutput, error) {
	req, out := c.UntagResourceRequest(input)
	return out, req.Send()
}

// UntagResourceWithContext is the same as UntagResource with the addition of
// the ability to pass a context and additional request options.
//
// See UntagResource for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UntagResourceWithContext(ctx aws.Context, input *UntagResourceInput, opts ...request.Option) (*UntagResourceOutput, error) {
	req, out := c.UntagResourceRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUpdateDataset = "UpdateDataset"

// UpdateDatasetRequest generates a "aws/request.Request" representing the
// client's request for the UpdateDataset operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UpdateDataset for more information on using the UpdateDataset
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UpdateDatasetRequest method.
//    req, resp := client.UpdateDatasetRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateDataset
func (c *GlueDataBrew) UpdateDatasetRequest(input *UpdateDatasetInput) (req *request.Request, output *UpdateDatasetOutput) {
	op := &request.Operation{
		Name:       opUpdateDataset,
		HTTPMethod: "PUT",
		HTTPPath:   "/datasets/{name}",
	}

	if input == nil {
		input = &UpdateDatasetInput{}
	}

	output = &UpdateDatasetOutput{}
	req = c.newRequest(op, input, output)
	return
}

// UpdateDataset API operation for AWS Glue DataBrew.
//
// Modifies the definition of an existing AWS Glue DataBrew dataset in the current
// AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UpdateDataset for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateDataset
func (c *GlueDataBrew) UpdateDataset(input *UpdateDatasetInput) (*UpdateDatasetOutput, error) {
	req, out := c.UpdateDatasetRequest(input)
	return out, req.Send()
}

// UpdateDatasetWithContext is the same as UpdateDataset with the addition of
// the ability to pass a context and additional request options.
//
// See UpdateDataset for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UpdateDatasetWithContext(ctx aws.Context, input *UpdateDatasetInput, opts ...request.Option) (*UpdateDatasetOutput, error) {
	req, out := c.UpdateDatasetRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUpdateProfileJob = "UpdateProfileJob"

// UpdateProfileJobRequest generates a "aws/request.Request" representing the
// client's request for the UpdateProfileJob operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UpdateProfileJob for more information on using the UpdateProfileJob
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UpdateProfileJobRequest method.
//    req, resp := client.UpdateProfileJobRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateProfileJob
func (c *GlueDataBrew) UpdateProfileJobRequest(input *UpdateProfileJobInput) (req *request.Request, output *UpdateProfileJobOutput) {
	op := &request.Operation{
		Name:       opUpdateProfileJob,
		HTTPMethod: "PUT",
		HTTPPath:   "/profileJobs/{name}",
	}

	if input == nil {
		input = &UpdateProfileJobInput{}
	}

	output = &UpdateProfileJobOutput{}
	req = c.newRequest(op, input, output)
	return
}

// UpdateProfileJob API operation for AWS Glue DataBrew.
//
// Modifies the definition of an existing AWS Glue DataBrew job in the current
// AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UpdateProfileJob for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateProfileJob
func (c *GlueDataBrew) UpdateProfileJob(input *UpdateProfileJobInput) (*UpdateProfileJobOutput, error) {
	req, out := c.UpdateProfileJobRequest(input)
	return out, req.Send()
}

// UpdateProfileJobWithContext is the same as UpdateProfileJob with the addition of
// the ability to pass a context and additional request options.
//
// See UpdateProfileJob for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UpdateProfileJobWithContext(ctx aws.Context, input *UpdateProfileJobInput, opts ...request.Option) (*UpdateProfileJobOutput, error) {
	req, out := c.UpdateProfileJobRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUpdateProject = "UpdateProject"

// UpdateProjectRequest generates a "aws/request.Request" representing the
// client's request for the UpdateProject operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UpdateProject for more information on using the UpdateProject
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UpdateProjectRequest method.
//    req, resp := client.UpdateProjectRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateProject
func (c *GlueDataBrew) UpdateProjectRequest(input *UpdateProjectInput) (req *request.Request, output *UpdateProjectOutput) {
	op := &request.Operation{
		Name:       opUpdateProject,
		HTTPMethod: "PUT",
		HTTPPath:   "/projects/{name}",
	}

	if input == nil {
		input = &UpdateProjectInput{}
	}

	output = &UpdateProjectOutput{}
	req = c.newRequest(op, input, output)
	return
}

// UpdateProject API operation for AWS Glue DataBrew.
//
// Modifies the definition of an existing AWS Glue DataBrew project in the current
// AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UpdateProject for usage and error information.
//
// Returned Error Types:
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateProject
func (c *GlueDataBrew) UpdateProject(input *UpdateProjectInput) (*UpdateProjectOutput, error) {
	req, out := c.UpdateProjectRequest(input)
	return out, req.Send()
}

// UpdateProjectWithContext is the same as UpdateProject with the addition of
// the ability to pass a context and additional request options.
//
// See UpdateProject for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UpdateProjectWithContext(ctx aws.Context, input *UpdateProjectInput, opts ...request.Option) (*UpdateProjectOutput, error) {
	req, out := c.UpdateProjectRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUpdateRecipe = "UpdateRecipe"

// UpdateRecipeRequest generates a "aws/request.Request" representing the
// client's request for the UpdateRecipe operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UpdateRecipe for more information on using the UpdateRecipe
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UpdateRecipeRequest method.
//    req, resp := client.UpdateRecipeRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateRecipe
func (c *GlueDataBrew) UpdateRecipeRequest(input *UpdateRecipeInput) (req *request.Request, output *UpdateRecipeOutput) {
	op := &request.Operation{
		Name:       opUpdateRecipe,
		HTTPMethod: "PUT",
		HTTPPath:   "/recipes/{name}",
	}

	if input == nil {
		input = &UpdateRecipeInput{}
	}

	output = &UpdateRecipeOutput{}
	req = c.newRequest(op, input, output)
	return
}

// UpdateRecipe API operation for AWS Glue DataBrew.
//
// Modifies the definition of the latest working version of an AWS Glue DataBrew
// recipe in the current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UpdateRecipe for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
//   * ResourceNotFoundException
//   One or more resources can't be found.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateRecipe
func (c *GlueDataBrew) UpdateRecipe(input *UpdateRecipeInput) (*UpdateRecipeOutput, error) {
	req, out := c.UpdateRecipeRequest(input)
	return out, req.Send()
}

// UpdateRecipeWithContext is the same as UpdateRecipe with the addition of
// the ability to pass a context and additional request options.
//
// See UpdateRecipe for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UpdateRecipeWithContext(ctx aws.Context, input *UpdateRecipeInput, opts ...request.Option) (*UpdateRecipeOutput, error) {
	req, out := c.UpdateRecipeRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUpdateRecipeJob = "UpdateRecipeJob"

// UpdateRecipeJobRequest generates a "aws/request.Request" representing the
// client's request for the UpdateRecipeJob operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UpdateRecipeJob for more information on using the UpdateRecipeJob
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UpdateRecipeJobRequest method.
//    req, resp := client.UpdateRecipeJobRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateRecipeJob
func (c *GlueDataBrew) UpdateRecipeJobRequest(input *UpdateRecipeJobInput) (req *request.Request, output *UpdateRecipeJobOutput) {
	op := &request.Operation{
		Name:       opUpdateRecipeJob,
		HTTPMethod: "PUT",
		HTTPPath:   "/recipeJobs/{name}",
	}

	if input == nil {
		input = &UpdateRecipeJobInput{}
	}

	output = &UpdateRecipeJobOutput{}
	req = c.newRequest(op, input, output)
	return
}

// UpdateRecipeJob API operation for AWS Glue DataBrew.
//
// Modifies the definition of an existing AWS Glue DataBrew recipe job in the
// current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UpdateRecipeJob for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateRecipeJob
func (c *GlueDataBrew) UpdateRecipeJob(input *UpdateRecipeJobInput) (*UpdateRecipeJobOutput, error) {
	req, out := c.UpdateRecipeJobRequest(input)
	return out, req.Send()
}

// UpdateRecipeJobWithContext is the same as UpdateRecipeJob with the addition of
// the ability to pass a context and additional request options.
//
// See UpdateRecipeJob for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UpdateRecipeJobWithContext(ctx aws.Context, input *UpdateRecipeJobInput, opts ...request.Option) (*UpdateRecipeJobOutput, error) {
	req, out := c.UpdateRecipeJobRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

const opUpdateSchedule = "UpdateSchedule"

// UpdateScheduleRequest generates a "aws/request.Request" representing the
// client's request for the UpdateSchedule operation. The "output" return
// value will be populated with the request's response once the request completes
// successfully.
//
// Use "Send" method on the returned Request to send the API call to the service.
// the "output" return value is not valid until after Send returns without error.
//
// See UpdateSchedule for more information on using the UpdateSchedule
// API call, and error handling.
//
// This method is useful when you want to inject custom logic or configuration
// into the SDK's request lifecycle. Such as custom headers, or retry logic.
//
//
//    // Example sending a request using the UpdateScheduleRequest method.
//    req, resp := client.UpdateScheduleRequest(params)
//
//    err := req.Send()
//    if err == nil { // resp is now filled
//        fmt.Println(resp)
//    }
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateSchedule
func (c *GlueDataBrew) UpdateScheduleRequest(input *UpdateScheduleInput) (req *request.Request, output *UpdateScheduleOutput) {
	op := &request.Operation{
		Name:       opUpdateSchedule,
		HTTPMethod: "PUT",
		HTTPPath:   "/schedules/{name}",
	}

	if input == nil {
		input = &UpdateScheduleInput{}
	}

	output = &UpdateScheduleOutput{}
	req = c.newRequest(op, input, output)
	return
}

// UpdateSchedule API operation for AWS Glue DataBrew.
//
// Modifies the definition of an existing AWS Glue DataBrew schedule in the
// current AWS account.
//
// Returns awserr.Error for service API and SDK errors. Use runtime type assertions
// with awserr.Error's Code and Message methods to get detailed information about
// the error.
//
// See the AWS API reference guide for AWS Glue DataBrew's
// API operation UpdateSchedule for usage and error information.
//
// Returned Error Types:
//   * ValidationException
//   The input parameters for this request failed validation.
//
// See also, https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/UpdateSchedule
func (c *GlueDataBrew) UpdateSchedule(input *UpdateScheduleInput) (*UpdateScheduleOutput, error) {
	req, out := c.UpdateScheduleRequest(input)
	return out, req.Send()
}

// UpdateScheduleWithContext is the same as UpdateSchedule with the addition of
// the ability to pass a context and additional request options.
//
// See UpdateSchedule for details on how to use this API operation.
//
// The context must be non-nil and will be used for request cancellation. If
// the context is nil a panic will occur. In the future the SDK may create
// sub-contexts for http.Requests. See https://golang.org/pkg/context/
// for more information on using Contexts.
func (c *GlueDataBrew) UpdateScheduleWithContext(ctx aws.Context, input *UpdateScheduleInput, opts ...request.Option) (*UpdateScheduleOutput, error) {
	req, out := c.UpdateScheduleRequest(input)
	req.SetContext(ctx)
	req.ApplyOptions(opts...)
	return out, req.Send()
}

// Access to the specified resource was denied.
type AccessDeniedException struct {
	_            struct{}                  `type:"structure"`
	RespMetadata protocol.ResponseMetadata `json:"-" xml:"-"`

	Message_ *string `locationName:"Message" type:"string"`
}

// String returns the string representation
func (s AccessDeniedException) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s AccessDeniedException) GoString() string {
	return s.String()
}

func newErrorAccessDeniedException(v protocol.ResponseMetadata) error {
	return &AccessDeniedException{
		RespMetadata: v,
	}
}

// Code returns the exception type name.
func (s *AccessDeniedException) Code() string {
	return "AccessDeniedException"
}

// Message returns the exception's message.
func (s *AccessDeniedException) Message() string {
	if s.Message_ != nil {
		return *s.Message_
	}
	return ""
}

// OrigErr always returns nil, satisfies awserr.Error interface.
func (s *AccessDeniedException) OrigErr() error {
	return nil
}

func (s *AccessDeniedException) Error() string {
	return fmt.Sprintf("%s: %s", s.Code(), s.Message())
}

// Status code returns the HTTP status code for the request's response error.
func (s *AccessDeniedException) StatusCode() int {
	return s.RespMetadata.StatusCode
}

// RequestID returns the service's response RequestID for request.
func (s *AccessDeniedException) RequestID() string {
	return s.RespMetadata.RequestID
}

type BatchDeleteRecipeVersionInput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe to be modified.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// An array of version identifiers to be deleted.
	//
	// RecipeVersions is a required field
	RecipeVersions []*string `min:"1" type:"list" required:"true"`
}

// String returns the string representation
func (s BatchDeleteRecipeVersionInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s BatchDeleteRecipeVersionInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *BatchDeleteRecipeVersionInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "BatchDeleteRecipeVersionInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RecipeVersions == nil {
		invalidParams.Add(request.NewErrParamRequired("RecipeVersions"))
	}
	if s.RecipeVersions != nil && len(s.RecipeVersions) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RecipeVersions", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *BatchDeleteRecipeVersionInput) SetName(v string) *BatchDeleteRecipeVersionInput {
	s.Name = &v
	return s
}

// SetRecipeVersions sets the RecipeVersions field's value.
func (s *BatchDeleteRecipeVersionInput) SetRecipeVersions(v []*string) *BatchDeleteRecipeVersionInput {
	s.RecipeVersions = v
	return s
}

type BatchDeleteRecipeVersionOutput struct {
	_ struct{} `type:"structure"`

	// Errors, if any, that were encountered when deleting the recipe versions.
	Errors []*RecipeVersionErrorDetail `type:"list"`

	// The name of the recipe that was modified.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s BatchDeleteRecipeVersionOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s BatchDeleteRecipeVersionOutput) GoString() string {
	return s.String()
}

// SetErrors sets the Errors field's value.
func (s *BatchDeleteRecipeVersionOutput) SetErrors(v []*RecipeVersionErrorDetail) *BatchDeleteRecipeVersionOutput {
	s.Errors = v
	return s
}

// SetName sets the Name field's value.
func (s *BatchDeleteRecipeVersionOutput) SetName(v string) *BatchDeleteRecipeVersionOutput {
	s.Name = &v
	return s
}

// Represents an individual condition that evaluates to true or false.
//
// Conditions are used with recipe actions: The action is only performed for
// column values where the condition evaluates to true.
//
// If a recipe requires more than one condition, then the recipe must specify
// multiple ConditionExpression elements. Each condition is applied to the rows
// in a dataset first, before the recipe action is performed.
type ConditionExpression struct {
	_ struct{} `type:"structure"`

	// A specific condition to apply to a recipe action. For more information, see
	// Recipe structure (https://docs.aws.amazon.com/databrew/latest/dg/recipe-structure.html)
	// in the AWS Glue DataBrew Developer Guide.
	//
	// Condition is a required field
	Condition *string `min:"1" type:"string" required:"true"`

	// A column to apply this condition to, within an AWS Glue DataBrew dataset.
	//
	// TargetColumn is a required field
	TargetColumn *string `min:"1" type:"string" required:"true"`

	// A value that the condition must evaluate to for the condition to succeed.
	Value *string `type:"string"`
}

// String returns the string representation
func (s ConditionExpression) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ConditionExpression) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ConditionExpression) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ConditionExpression"}
	if s.Condition == nil {
		invalidParams.Add(request.NewErrParamRequired("Condition"))
	}
	if s.Condition != nil && len(*s.Condition) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Condition", 1))
	}
	if s.TargetColumn == nil {
		invalidParams.Add(request.NewErrParamRequired("TargetColumn"))
	}
	if s.TargetColumn != nil && len(*s.TargetColumn) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("TargetColumn", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetCondition sets the Condition field's value.
func (s *ConditionExpression) SetCondition(v string) *ConditionExpression {
	s.Condition = &v
	return s
}

// SetTargetColumn sets the TargetColumn field's value.
func (s *ConditionExpression) SetTargetColumn(v string) *ConditionExpression {
	s.TargetColumn = &v
	return s
}

// SetValue sets the Value field's value.
func (s *ConditionExpression) SetValue(v string) *ConditionExpression {
	s.Value = &v
	return s
}

// Updating or deleting a resource can cause an inconsistent state.
type ConflictException struct {
	_            struct{}                  `type:"structure"`
	RespMetadata protocol.ResponseMetadata `json:"-" xml:"-"`

	Message_ *string `locationName:"Message" type:"string"`
}

// String returns the string representation
func (s ConflictException) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ConflictException) GoString() string {
	return s.String()
}

func newErrorConflictException(v protocol.ResponseMetadata) error {
	return &ConflictException{
		RespMetadata: v,
	}
}

// Code returns the exception type name.
func (s *ConflictException) Code() string {
	return "ConflictException"
}

// Message returns the exception's message.
func (s *ConflictException) Message() string {
	if s.Message_ != nil {
		return *s.Message_
	}
	return ""
}

// OrigErr always returns nil, satisfies awserr.Error interface.
func (s *ConflictException) OrigErr() error {
	return nil
}

func (s *ConflictException) Error() string {
	return fmt.Sprintf("%s: %s", s.Code(), s.Message())
}

// Status code returns the HTTP status code for the request's response error.
func (s *ConflictException) StatusCode() int {
	return s.RespMetadata.StatusCode
}

// RequestID returns the service's response RequestID for request.
func (s *ConflictException) RequestID() string {
	return s.RespMetadata.RequestID
}

type CreateDatasetInput struct {
	_ struct{} `type:"structure"`

	// Options that define how Microsoft Excel input is to be interpreted by DataBrew.
	FormatOptions *FormatOptions `type:"structure"`

	// Information on how AWS Glue DataBrew can find data, in either the AWS Glue
	// Data Catalog or Amazon S3.
	//
	// Input is a required field
	Input *Input `type:"structure" required:"true"`

	// The name of the dataset to be created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// Metadata tags to apply to this dataset.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s CreateDatasetInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateDatasetInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *CreateDatasetInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "CreateDatasetInput"}
	if s.Input == nil {
		invalidParams.Add(request.NewErrParamRequired("Input"))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}
	if s.FormatOptions != nil {
		if err := s.FormatOptions.Validate(); err != nil {
			invalidParams.AddNested("FormatOptions", err.(request.ErrInvalidParams))
		}
	}
	if s.Input != nil {
		if err := s.Input.Validate(); err != nil {
			invalidParams.AddNested("Input", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetFormatOptions sets the FormatOptions field's value.
func (s *CreateDatasetInput) SetFormatOptions(v *FormatOptions) *CreateDatasetInput {
	s.FormatOptions = v
	return s
}

// SetInput sets the Input field's value.
func (s *CreateDatasetInput) SetInput(v *Input) *CreateDatasetInput {
	s.Input = v
	return s
}

// SetName sets the Name field's value.
func (s *CreateDatasetInput) SetName(v string) *CreateDatasetInput {
	s.Name = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *CreateDatasetInput) SetTags(v map[string]*string) *CreateDatasetInput {
	s.Tags = v
	return s
}

type CreateDatasetOutput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset that you created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s CreateDatasetOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateDatasetOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *CreateDatasetOutput) SetName(v string) *CreateDatasetOutput {
	s.Name = &v
	return s
}

type CreateProfileJobInput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset that this job is to act upon.
	//
	// DatasetName is a required field
	DatasetName *string `min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) of an encryption key that is used to protect
	// the job.
	EncryptionKeyArn *string `min:"20" type:"string"`

	// The encryption mode for the job, which can be one of the following:
	//
	//    * SSE-KMS - para>SSE-KMS - server-side encryption with AWS KMS-managed
	//    keys.
	//
	//    * SSE-S3 - Server-side encryption with keys managed by Amazon S3.
	EncryptionMode *string `type:"string" enum:"EncryptionMode"`

	// A value that enables or disables Amazon CloudWatch logging for the current
	// AWS account. If logging is enabled, CloudWatch writes one log stream for
	// each job run.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// The maximum number of nodes that DataBrew can use when the job processes
	// data.
	MaxCapacity *int64 `type:"integer"`

	// The maximum number of times to retry the job after a job run fails.
	MaxRetries *int64 `type:"integer"`

	// The name of the job to be created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// An Amazon S3 location (bucket name an object key) where DataBrew can read
	// input data, or write output from a job.
	//
	// OutputLocation is a required field
	OutputLocation *S3Location `type:"structure" required:"true"`

	// The Amazon Resource Name (ARN) of the AWS Identity and Access Management
	// (IAM) role to be assumed for this request.
	//
	// RoleArn is a required field
	RoleArn *string `min:"20" type:"string" required:"true"`

	// Metadata tags to apply to this job.
	Tags map[string]*string `min:"1" type:"map"`

	// The job's timeout in minutes. A job that attempts to run longer than this
	// timeout period ends with a status of TIMEOUT.
	Timeout *int64 `type:"integer"`
}

// String returns the string representation
func (s CreateProfileJobInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateProfileJobInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *CreateProfileJobInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "CreateProfileJobInput"}
	if s.DatasetName == nil {
		invalidParams.Add(request.NewErrParamRequired("DatasetName"))
	}
	if s.DatasetName != nil && len(*s.DatasetName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("DatasetName", 1))
	}
	if s.EncryptionKeyArn != nil && len(*s.EncryptionKeyArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("EncryptionKeyArn", 20))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.OutputLocation == nil {
		invalidParams.Add(request.NewErrParamRequired("OutputLocation"))
	}
	if s.RoleArn == nil {
		invalidParams.Add(request.NewErrParamRequired("RoleArn"))
	}
	if s.RoleArn != nil && len(*s.RoleArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("RoleArn", 20))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}
	if s.OutputLocation != nil {
		if err := s.OutputLocation.Validate(); err != nil {
			invalidParams.AddNested("OutputLocation", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDatasetName sets the DatasetName field's value.
func (s *CreateProfileJobInput) SetDatasetName(v string) *CreateProfileJobInput {
	s.DatasetName = &v
	return s
}

// SetEncryptionKeyArn sets the EncryptionKeyArn field's value.
func (s *CreateProfileJobInput) SetEncryptionKeyArn(v string) *CreateProfileJobInput {
	s.EncryptionKeyArn = &v
	return s
}

// SetEncryptionMode sets the EncryptionMode field's value.
func (s *CreateProfileJobInput) SetEncryptionMode(v string) *CreateProfileJobInput {
	s.EncryptionMode = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *CreateProfileJobInput) SetLogSubscription(v string) *CreateProfileJobInput {
	s.LogSubscription = &v
	return s
}

// SetMaxCapacity sets the MaxCapacity field's value.
func (s *CreateProfileJobInput) SetMaxCapacity(v int64) *CreateProfileJobInput {
	s.MaxCapacity = &v
	return s
}

// SetMaxRetries sets the MaxRetries field's value.
func (s *CreateProfileJobInput) SetMaxRetries(v int64) *CreateProfileJobInput {
	s.MaxRetries = &v
	return s
}

// SetName sets the Name field's value.
func (s *CreateProfileJobInput) SetName(v string) *CreateProfileJobInput {
	s.Name = &v
	return s
}

// SetOutputLocation sets the OutputLocation field's value.
func (s *CreateProfileJobInput) SetOutputLocation(v *S3Location) *CreateProfileJobInput {
	s.OutputLocation = v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *CreateProfileJobInput) SetRoleArn(v string) *CreateProfileJobInput {
	s.RoleArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *CreateProfileJobInput) SetTags(v map[string]*string) *CreateProfileJobInput {
	s.Tags = v
	return s
}

// SetTimeout sets the Timeout field's value.
func (s *CreateProfileJobInput) SetTimeout(v int64) *CreateProfileJobInput {
	s.Timeout = &v
	return s
}

type CreateProfileJobOutput struct {
	_ struct{} `type:"structure"`

	// The name of the job that was created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s CreateProfileJobOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateProfileJobOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *CreateProfileJobOutput) SetName(v string) *CreateProfileJobOutput {
	s.Name = &v
	return s
}

type CreateProjectInput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset to associate this project with.
	//
	// DatasetName is a required field
	DatasetName *string `min:"1" type:"string" required:"true"`

	// A unique name for the new project.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The name of an existing recipe to associate with the project.
	//
	// RecipeName is a required field
	RecipeName *string `min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) of the AWS Identity and Access Management
	// (IAM) role to be assumed for this request.
	//
	// RoleArn is a required field
	RoleArn *string `min:"20" type:"string" required:"true"`

	// Represents the sample size and sampling type for AWS Glue DataBrew to use
	// for interactive data analysis.
	Sample *Sample `type:"structure"`

	// Metadata tags to apply to this project.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s CreateProjectInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateProjectInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *CreateProjectInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "CreateProjectInput"}
	if s.DatasetName == nil {
		invalidParams.Add(request.NewErrParamRequired("DatasetName"))
	}
	if s.DatasetName != nil && len(*s.DatasetName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("DatasetName", 1))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RecipeName == nil {
		invalidParams.Add(request.NewErrParamRequired("RecipeName"))
	}
	if s.RecipeName != nil && len(*s.RecipeName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RecipeName", 1))
	}
	if s.RoleArn == nil {
		invalidParams.Add(request.NewErrParamRequired("RoleArn"))
	}
	if s.RoleArn != nil && len(*s.RoleArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("RoleArn", 20))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}
	if s.Sample != nil {
		if err := s.Sample.Validate(); err != nil {
			invalidParams.AddNested("Sample", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDatasetName sets the DatasetName field's value.
func (s *CreateProjectInput) SetDatasetName(v string) *CreateProjectInput {
	s.DatasetName = &v
	return s
}

// SetName sets the Name field's value.
func (s *CreateProjectInput) SetName(v string) *CreateProjectInput {
	s.Name = &v
	return s
}

// SetRecipeName sets the RecipeName field's value.
func (s *CreateProjectInput) SetRecipeName(v string) *CreateProjectInput {
	s.RecipeName = &v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *CreateProjectInput) SetRoleArn(v string) *CreateProjectInput {
	s.RoleArn = &v
	return s
}

// SetSample sets the Sample field's value.
func (s *CreateProjectInput) SetSample(v *Sample) *CreateProjectInput {
	s.Sample = v
	return s
}

// SetTags sets the Tags field's value.
func (s *CreateProjectInput) SetTags(v map[string]*string) *CreateProjectInput {
	s.Tags = v
	return s
}

type CreateProjectOutput struct {
	_ struct{} `type:"structure"`

	// The name of the project that you created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s CreateProjectOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateProjectOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *CreateProjectOutput) SetName(v string) *CreateProjectOutput {
	s.Name = &v
	return s
}

type CreateRecipeInput struct {
	_ struct{} `type:"structure"`

	// A description for the recipe.
	Description *string `type:"string"`

	// A unique name for the recipe.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// An array containing the steps to be performed by the recipe. Each recipe
	// step consists of one recipe action and (optionally) an array of condition
	// expressions.
	//
	// Steps is a required field
	Steps []*RecipeStep `type:"list" required:"true"`

	// Metadata tags to apply to this recipe.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s CreateRecipeInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateRecipeInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *CreateRecipeInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "CreateRecipeInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.Steps == nil {
		invalidParams.Add(request.NewErrParamRequired("Steps"))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}
	if s.Steps != nil {
		for i, v := range s.Steps {
			if v == nil {
				continue
			}
			if err := v.Validate(); err != nil {
				invalidParams.AddNested(fmt.Sprintf("%s[%v]", "Steps", i), err.(request.ErrInvalidParams))
			}
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDescription sets the Description field's value.
func (s *CreateRecipeInput) SetDescription(v string) *CreateRecipeInput {
	s.Description = &v
	return s
}

// SetName sets the Name field's value.
func (s *CreateRecipeInput) SetName(v string) *CreateRecipeInput {
	s.Name = &v
	return s
}

// SetSteps sets the Steps field's value.
func (s *CreateRecipeInput) SetSteps(v []*RecipeStep) *CreateRecipeInput {
	s.Steps = v
	return s
}

// SetTags sets the Tags field's value.
func (s *CreateRecipeInput) SetTags(v map[string]*string) *CreateRecipeInput {
	s.Tags = v
	return s
}

type CreateRecipeJobInput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset that this job processes.
	DatasetName *string `min:"1" type:"string"`

	// The Amazon Resource Name (ARN) of an encryption key that is used to protect
	// the job.
	EncryptionKeyArn *string `min:"20" type:"string"`

	// The encryption mode for the job, which can be one of the following:
	//
	//    * SSE-KMS - Server-side encryption with AWS KMS-managed keys.
	//
	//    * SSE-S3 - Server-side encryption with keys managed by Amazon S3.
	EncryptionMode *string `type:"string" enum:"EncryptionMode"`

	// A value that enables or disables Amazon CloudWatch logging for the current
	// AWS account. If logging is enabled, CloudWatch writes one log stream for
	// each job run.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// The maximum number of nodes that DataBrew can consume when the job processes
	// data.
	MaxCapacity *int64 `type:"integer"`

	// The maximum number of times to retry the job after a job run fails.
	MaxRetries *int64 `type:"integer"`

	// A unique name for the job.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// One or more artifacts that represent the output from running the job.
	//
	// Outputs is a required field
	Outputs []*Output `min:"1" type:"list" required:"true"`

	// Either the name of an existing project, or a combination of a recipe and
	// a dataset to associate with the recipe.
	ProjectName *string `min:"1" type:"string"`

	// Represents all of the attributes of an AWS Glue DataBrew recipe.
	RecipeReference *RecipeReference `type:"structure"`

	// The Amazon Resource Name (ARN) of the AWS Identity and Access Management
	// (IAM) role to be assumed for this request.
	//
	// RoleArn is a required field
	RoleArn *string `min:"20" type:"string" required:"true"`

	// Metadata tags to apply to this job dataset.
	Tags map[string]*string `min:"1" type:"map"`

	// The job's timeout in minutes. A job that attempts to run longer than this
	// timeout period ends with a status of TIMEOUT.
	Timeout *int64 `type:"integer"`
}

// String returns the string representation
func (s CreateRecipeJobInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateRecipeJobInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *CreateRecipeJobInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "CreateRecipeJobInput"}
	if s.DatasetName != nil && len(*s.DatasetName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("DatasetName", 1))
	}
	if s.EncryptionKeyArn != nil && len(*s.EncryptionKeyArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("EncryptionKeyArn", 20))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.Outputs == nil {
		invalidParams.Add(request.NewErrParamRequired("Outputs"))
	}
	if s.Outputs != nil && len(s.Outputs) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Outputs", 1))
	}
	if s.ProjectName != nil && len(*s.ProjectName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("ProjectName", 1))
	}
	if s.RoleArn == nil {
		invalidParams.Add(request.NewErrParamRequired("RoleArn"))
	}
	if s.RoleArn != nil && len(*s.RoleArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("RoleArn", 20))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}
	if s.Outputs != nil {
		for i, v := range s.Outputs {
			if v == nil {
				continue
			}
			if err := v.Validate(); err != nil {
				invalidParams.AddNested(fmt.Sprintf("%s[%v]", "Outputs", i), err.(request.ErrInvalidParams))
			}
		}
	}
	if s.RecipeReference != nil {
		if err := s.RecipeReference.Validate(); err != nil {
			invalidParams.AddNested("RecipeReference", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDatasetName sets the DatasetName field's value.
func (s *CreateRecipeJobInput) SetDatasetName(v string) *CreateRecipeJobInput {
	s.DatasetName = &v
	return s
}

// SetEncryptionKeyArn sets the EncryptionKeyArn field's value.
func (s *CreateRecipeJobInput) SetEncryptionKeyArn(v string) *CreateRecipeJobInput {
	s.EncryptionKeyArn = &v
	return s
}

// SetEncryptionMode sets the EncryptionMode field's value.
func (s *CreateRecipeJobInput) SetEncryptionMode(v string) *CreateRecipeJobInput {
	s.EncryptionMode = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *CreateRecipeJobInput) SetLogSubscription(v string) *CreateRecipeJobInput {
	s.LogSubscription = &v
	return s
}

// SetMaxCapacity sets the MaxCapacity field's value.
func (s *CreateRecipeJobInput) SetMaxCapacity(v int64) *CreateRecipeJobInput {
	s.MaxCapacity = &v
	return s
}

// SetMaxRetries sets the MaxRetries field's value.
func (s *CreateRecipeJobInput) SetMaxRetries(v int64) *CreateRecipeJobInput {
	s.MaxRetries = &v
	return s
}

// SetName sets the Name field's value.
func (s *CreateRecipeJobInput) SetName(v string) *CreateRecipeJobInput {
	s.Name = &v
	return s
}

// SetOutputs sets the Outputs field's value.
func (s *CreateRecipeJobInput) SetOutputs(v []*Output) *CreateRecipeJobInput {
	s.Outputs = v
	return s
}

// SetProjectName sets the ProjectName field's value.
func (s *CreateRecipeJobInput) SetProjectName(v string) *CreateRecipeJobInput {
	s.ProjectName = &v
	return s
}

// SetRecipeReference sets the RecipeReference field's value.
func (s *CreateRecipeJobInput) SetRecipeReference(v *RecipeReference) *CreateRecipeJobInput {
	s.RecipeReference = v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *CreateRecipeJobInput) SetRoleArn(v string) *CreateRecipeJobInput {
	s.RoleArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *CreateRecipeJobInput) SetTags(v map[string]*string) *CreateRecipeJobInput {
	s.Tags = v
	return s
}

// SetTimeout sets the Timeout field's value.
func (s *CreateRecipeJobInput) SetTimeout(v int64) *CreateRecipeJobInput {
	s.Timeout = &v
	return s
}

type CreateRecipeJobOutput struct {
	_ struct{} `type:"structure"`

	// The name of the job that you created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s CreateRecipeJobOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateRecipeJobOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *CreateRecipeJobOutput) SetName(v string) *CreateRecipeJobOutput {
	s.Name = &v
	return s
}

type CreateRecipeOutput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe that you created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s CreateRecipeOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateRecipeOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *CreateRecipeOutput) SetName(v string) *CreateRecipeOutput {
	s.Name = &v
	return s
}

type CreateScheduleInput struct {
	_ struct{} `type:"structure"`

	// The date or dates and time or times, in cron format, when the jobs are to
	// be run.
	//
	// CronExpression is a required field
	CronExpression *string `min:"1" type:"string" required:"true"`

	// The name or names of one or more jobs to be run.
	JobNames []*string `type:"list"`

	// A unique name for the schedule.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// Metadata tags to apply to this schedule.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s CreateScheduleInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateScheduleInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *CreateScheduleInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "CreateScheduleInput"}
	if s.CronExpression == nil {
		invalidParams.Add(request.NewErrParamRequired("CronExpression"))
	}
	if s.CronExpression != nil && len(*s.CronExpression) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("CronExpression", 1))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetCronExpression sets the CronExpression field's value.
func (s *CreateScheduleInput) SetCronExpression(v string) *CreateScheduleInput {
	s.CronExpression = &v
	return s
}

// SetJobNames sets the JobNames field's value.
func (s *CreateScheduleInput) SetJobNames(v []*string) *CreateScheduleInput {
	s.JobNames = v
	return s
}

// SetName sets the Name field's value.
func (s *CreateScheduleInput) SetName(v string) *CreateScheduleInput {
	s.Name = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *CreateScheduleInput) SetTags(v map[string]*string) *CreateScheduleInput {
	s.Tags = v
	return s
}

type CreateScheduleOutput struct {
	_ struct{} `type:"structure"`

	// The name of the schedule that was created.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s CreateScheduleOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s CreateScheduleOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *CreateScheduleOutput) SetName(v string) *CreateScheduleOutput {
	s.Name = &v
	return s
}

// Represents how metadata stored in the AWS Glue Data Catalog is defined in
// an AWS Glue DataBrew dataset.
type DataCatalogInputDefinition struct {
	_ struct{} `type:"structure"`

	// The unique identifier of the AWS account that holds the Data Catalog that
	// stores the data.
	CatalogId *string `min:"1" type:"string"`

	// The name of a database in the Data Catalog.
	//
	// DatabaseName is a required field
	DatabaseName *string `min:"1" type:"string" required:"true"`

	// The name of a database table in the Data Catalog. This table corresponds
	// to a DataBrew dataset.
	//
	// TableName is a required field
	TableName *string `min:"1" type:"string" required:"true"`

	// An Amazon location that AWS Glue Data Catalog can use as a temporary directory.
	TempDirectory *S3Location `type:"structure"`
}

// String returns the string representation
func (s DataCatalogInputDefinition) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DataCatalogInputDefinition) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DataCatalogInputDefinition) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DataCatalogInputDefinition"}
	if s.CatalogId != nil && len(*s.CatalogId) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("CatalogId", 1))
	}
	if s.DatabaseName == nil {
		invalidParams.Add(request.NewErrParamRequired("DatabaseName"))
	}
	if s.DatabaseName != nil && len(*s.DatabaseName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("DatabaseName", 1))
	}
	if s.TableName == nil {
		invalidParams.Add(request.NewErrParamRequired("TableName"))
	}
	if s.TableName != nil && len(*s.TableName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("TableName", 1))
	}
	if s.TempDirectory != nil {
		if err := s.TempDirectory.Validate(); err != nil {
			invalidParams.AddNested("TempDirectory", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetCatalogId sets the CatalogId field's value.
func (s *DataCatalogInputDefinition) SetCatalogId(v string) *DataCatalogInputDefinition {
	s.CatalogId = &v
	return s
}

// SetDatabaseName sets the DatabaseName field's value.
func (s *DataCatalogInputDefinition) SetDatabaseName(v string) *DataCatalogInputDefinition {
	s.DatabaseName = &v
	return s
}

// SetTableName sets the TableName field's value.
func (s *DataCatalogInputDefinition) SetTableName(v string) *DataCatalogInputDefinition {
	s.TableName = &v
	return s
}

// SetTempDirectory sets the TempDirectory field's value.
func (s *DataCatalogInputDefinition) SetTempDirectory(v *S3Location) *DataCatalogInputDefinition {
	s.TempDirectory = v
	return s
}

// Represents a dataset that can be processed by AWS Glue DataBrew.
type Dataset struct {
	_ struct{} `type:"structure"`

	// The ID of the AWS account that owns the dataset.
	AccountId *string `type:"string"`

	// The date and time that the dataset was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (the user name) of the user who created the dataset.
	CreatedBy *string `type:"string"`

	// Options that define how DataBrew interprets the data in the dataset.
	FormatOptions *FormatOptions `type:"structure"`

	// Information on how DataBrew can find the dataset, in either the AWS Glue
	// Data Catalog or Amazon S3.
	//
	// Input is a required field
	Input *Input `type:"structure" required:"true"`

	// The identifier (the user name) of the user who last modified the dataset.
	LastModifiedBy *string `type:"string"`

	// The last modification date and time of the dataset.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The unique name of the dataset.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The unique Amazon Resource Name (ARN) for the dataset.
	ResourceArn *string `min:"20" type:"string"`

	// The location of the data for the dataset, either Amazon S3 or the AWS Glue
	// Data Catalog.
	Source *string `type:"string" enum:"Source"`

	// Metadata tags that have been applied to the dataset.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s Dataset) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Dataset) GoString() string {
	return s.String()
}

// SetAccountId sets the AccountId field's value.
func (s *Dataset) SetAccountId(v string) *Dataset {
	s.AccountId = &v
	return s
}

// SetCreateDate sets the CreateDate field's value.
func (s *Dataset) SetCreateDate(v time.Time) *Dataset {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *Dataset) SetCreatedBy(v string) *Dataset {
	s.CreatedBy = &v
	return s
}

// SetFormatOptions sets the FormatOptions field's value.
func (s *Dataset) SetFormatOptions(v *FormatOptions) *Dataset {
	s.FormatOptions = v
	return s
}

// SetInput sets the Input field's value.
func (s *Dataset) SetInput(v *Input) *Dataset {
	s.Input = v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *Dataset) SetLastModifiedBy(v string) *Dataset {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *Dataset) SetLastModifiedDate(v time.Time) *Dataset {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *Dataset) SetName(v string) *Dataset {
	s.Name = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *Dataset) SetResourceArn(v string) *Dataset {
	s.ResourceArn = &v
	return s
}

// SetSource sets the Source field's value.
func (s *Dataset) SetSource(v string) *Dataset {
	s.Source = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *Dataset) SetTags(v map[string]*string) *Dataset {
	s.Tags = v
	return s
}

type DeleteDatasetInput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset to be deleted.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteDatasetInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteDatasetInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DeleteDatasetInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DeleteDatasetInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DeleteDatasetInput) SetName(v string) *DeleteDatasetInput {
	s.Name = &v
	return s
}

type DeleteDatasetOutput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset that you deleted.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteDatasetOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteDatasetOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *DeleteDatasetOutput) SetName(v string) *DeleteDatasetOutput {
	s.Name = &v
	return s
}

type DeleteJobInput struct {
	_ struct{} `type:"structure"`

	// The name of the job to be deleted.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteJobInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteJobInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DeleteJobInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DeleteJobInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DeleteJobInput) SetName(v string) *DeleteJobInput {
	s.Name = &v
	return s
}

type DeleteJobOutput struct {
	_ struct{} `type:"structure"`

	// The name of the job that you deleted.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteJobOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteJobOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *DeleteJobOutput) SetName(v string) *DeleteJobOutput {
	s.Name = &v
	return s
}

type DeleteProjectInput struct {
	_ struct{} `type:"structure"`

	// The name of the project to be deleted.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteProjectInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteProjectInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DeleteProjectInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DeleteProjectInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DeleteProjectInput) SetName(v string) *DeleteProjectInput {
	s.Name = &v
	return s
}

type DeleteProjectOutput struct {
	_ struct{} `type:"structure"`

	// The name of the project that you deleted.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteProjectOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteProjectOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *DeleteProjectOutput) SetName(v string) *DeleteProjectOutput {
	s.Name = &v
	return s
}

type DeleteRecipeVersionInput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe to be deleted.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// The version of the recipe to be deleted.
	//
	// RecipeVersion is a required field
	RecipeVersion *string `location:"uri" locationName:"recipeVersion" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteRecipeVersionInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteRecipeVersionInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DeleteRecipeVersionInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DeleteRecipeVersionInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RecipeVersion == nil {
		invalidParams.Add(request.NewErrParamRequired("RecipeVersion"))
	}
	if s.RecipeVersion != nil && len(*s.RecipeVersion) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RecipeVersion", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DeleteRecipeVersionInput) SetName(v string) *DeleteRecipeVersionInput {
	s.Name = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *DeleteRecipeVersionInput) SetRecipeVersion(v string) *DeleteRecipeVersionInput {
	s.RecipeVersion = &v
	return s
}

type DeleteRecipeVersionOutput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe that was deleted.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The version of the recipe that was deleted.
	//
	// RecipeVersion is a required field
	RecipeVersion *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteRecipeVersionOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteRecipeVersionOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *DeleteRecipeVersionOutput) SetName(v string) *DeleteRecipeVersionOutput {
	s.Name = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *DeleteRecipeVersionOutput) SetRecipeVersion(v string) *DeleteRecipeVersionOutput {
	s.RecipeVersion = &v
	return s
}

type DeleteScheduleInput struct {
	_ struct{} `type:"structure"`

	// The name of the schedule to be deleted.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteScheduleInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteScheduleInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DeleteScheduleInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DeleteScheduleInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DeleteScheduleInput) SetName(v string) *DeleteScheduleInput {
	s.Name = &v
	return s
}

type DeleteScheduleOutput struct {
	_ struct{} `type:"structure"`

	// The name of the schedule that was deleted.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DeleteScheduleOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DeleteScheduleOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *DeleteScheduleOutput) SetName(v string) *DeleteScheduleOutput {
	s.Name = &v
	return s
}

type DescribeDatasetInput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset to be described.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DescribeDatasetInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeDatasetInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DescribeDatasetInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DescribeDatasetInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DescribeDatasetInput) SetName(v string) *DescribeDatasetInput {
	s.Name = &v
	return s
}

type DescribeDatasetOutput struct {
	_ struct{} `type:"structure"`

	// The date and time that the dataset was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (user name) of the user who created the dataset.
	CreatedBy *string `type:"string"`

	// Options that define how Microsoft Excel input is to be interpreted by DataBrew.
	FormatOptions *FormatOptions `type:"structure"`

	// Information on how AWS Glue DataBrew can find data, in either the AWS Glue
	// Data Catalog or Amazon S3.
	//
	// Input is a required field
	Input *Input `type:"structure" required:"true"`

	// The identifier (user name) of the user who last modified the dataset.
	LastModifiedBy *string `type:"string"`

	// The date and time that the dataset was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The name of the dataset.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) of the dataset.
	ResourceArn *string `min:"20" type:"string"`

	// The location of the data for this dataset, Amazon S3 or the AWS Glue Data
	// Catalog.
	Source *string `type:"string" enum:"Source"`

	// Metadata tags associated with this dataset.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s DescribeDatasetOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeDatasetOutput) GoString() string {
	return s.String()
}

// SetCreateDate sets the CreateDate field's value.
func (s *DescribeDatasetOutput) SetCreateDate(v time.Time) *DescribeDatasetOutput {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *DescribeDatasetOutput) SetCreatedBy(v string) *DescribeDatasetOutput {
	s.CreatedBy = &v
	return s
}

// SetFormatOptions sets the FormatOptions field's value.
func (s *DescribeDatasetOutput) SetFormatOptions(v *FormatOptions) *DescribeDatasetOutput {
	s.FormatOptions = v
	return s
}

// SetInput sets the Input field's value.
func (s *DescribeDatasetOutput) SetInput(v *Input) *DescribeDatasetOutput {
	s.Input = v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *DescribeDatasetOutput) SetLastModifiedBy(v string) *DescribeDatasetOutput {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *DescribeDatasetOutput) SetLastModifiedDate(v time.Time) *DescribeDatasetOutput {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *DescribeDatasetOutput) SetName(v string) *DescribeDatasetOutput {
	s.Name = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *DescribeDatasetOutput) SetResourceArn(v string) *DescribeDatasetOutput {
	s.ResourceArn = &v
	return s
}

// SetSource sets the Source field's value.
func (s *DescribeDatasetOutput) SetSource(v string) *DescribeDatasetOutput {
	s.Source = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *DescribeDatasetOutput) SetTags(v map[string]*string) *DescribeDatasetOutput {
	s.Tags = v
	return s
}

type DescribeJobInput struct {
	_ struct{} `type:"structure"`

	// The name of the job to be described.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DescribeJobInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeJobInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DescribeJobInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DescribeJobInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DescribeJobInput) SetName(v string) *DescribeJobInput {
	s.Name = &v
	return s
}

type DescribeJobOutput struct {
	_ struct{} `type:"structure"`

	// The date and time that the job was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (user name) of the user associated with the creation of the
	// job.
	CreatedBy *string `type:"string"`

	// The dataset that the job acts upon.
	DatasetName *string `min:"1" type:"string"`

	// The Amazon Resource Name (ARN) of an encryption key that is used to protect
	// the job.
	EncryptionKeyArn *string `min:"20" type:"string"`

	// The encryption mode for the job, which can be one of the following:
	//
	//    * SSE-KMS - Server-side encryption with AWS KMS-managed keys.
	//
	//    * SSE-S3 - Server-side encryption with keys managed by Amazon S3.
	EncryptionMode *string `type:"string" enum:"EncryptionMode"`

	// The identifier (user name) of the user who last modified the job.
	LastModifiedBy *string `type:"string"`

	// The date and time that the job was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// A value that indicates whether Amazon CloudWatch logging is enabled for this
	// job.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// The maximum number of nodes that AWS Glue DataBrew can consume when the job
	// processes data.
	MaxCapacity *int64 `type:"integer"`

	// The maximum number of times to retry the job after a job run fails.
	MaxRetries *int64 `type:"integer"`

	// The name of the job.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// One or more artifacts that represent the output from running the job.
	Outputs []*Output `min:"1" type:"list"`

	// The DataBrew project associated with this job.
	ProjectName *string `min:"1" type:"string"`

	// Represents all of the attributes of an AWS Glue DataBrew recipe.
	RecipeReference *RecipeReference `type:"structure"`

	// The Amazon Resource Name (ARN) of the job.
	ResourceArn *string `min:"20" type:"string"`

	// The ARN of the AWS Identity and Access Management (IAM) role that was assumed
	// for this request.
	RoleArn *string `min:"20" type:"string"`

	// Metadata tags associated with this job.
	Tags map[string]*string `min:"1" type:"map"`

	// The job's timeout in minutes. A job that attempts to run longer than this
	// timeout period ends with a status of TIMEOUT.
	Timeout *int64 `type:"integer"`

	// The job type, which must be one of the following:
	//
	//    * PROFILE - The job analyzes the dataset to determine its size, data types,
	//    data distribution, and more.
	//
	//    * RECIPE - The job applies one or more transformations to a dataset.
	Type *string `type:"string" enum:"JobType"`
}

// String returns the string representation
func (s DescribeJobOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeJobOutput) GoString() string {
	return s.String()
}

// SetCreateDate sets the CreateDate field's value.
func (s *DescribeJobOutput) SetCreateDate(v time.Time) *DescribeJobOutput {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *DescribeJobOutput) SetCreatedBy(v string) *DescribeJobOutput {
	s.CreatedBy = &v
	return s
}

// SetDatasetName sets the DatasetName field's value.
func (s *DescribeJobOutput) SetDatasetName(v string) *DescribeJobOutput {
	s.DatasetName = &v
	return s
}

// SetEncryptionKeyArn sets the EncryptionKeyArn field's value.
func (s *DescribeJobOutput) SetEncryptionKeyArn(v string) *DescribeJobOutput {
	s.EncryptionKeyArn = &v
	return s
}

// SetEncryptionMode sets the EncryptionMode field's value.
func (s *DescribeJobOutput) SetEncryptionMode(v string) *DescribeJobOutput {
	s.EncryptionMode = &v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *DescribeJobOutput) SetLastModifiedBy(v string) *DescribeJobOutput {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *DescribeJobOutput) SetLastModifiedDate(v time.Time) *DescribeJobOutput {
	s.LastModifiedDate = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *DescribeJobOutput) SetLogSubscription(v string) *DescribeJobOutput {
	s.LogSubscription = &v
	return s
}

// SetMaxCapacity sets the MaxCapacity field's value.
func (s *DescribeJobOutput) SetMaxCapacity(v int64) *DescribeJobOutput {
	s.MaxCapacity = &v
	return s
}

// SetMaxRetries sets the MaxRetries field's value.
func (s *DescribeJobOutput) SetMaxRetries(v int64) *DescribeJobOutput {
	s.MaxRetries = &v
	return s
}

// SetName sets the Name field's value.
func (s *DescribeJobOutput) SetName(v string) *DescribeJobOutput {
	s.Name = &v
	return s
}

// SetOutputs sets the Outputs field's value.
func (s *DescribeJobOutput) SetOutputs(v []*Output) *DescribeJobOutput {
	s.Outputs = v
	return s
}

// SetProjectName sets the ProjectName field's value.
func (s *DescribeJobOutput) SetProjectName(v string) *DescribeJobOutput {
	s.ProjectName = &v
	return s
}

// SetRecipeReference sets the RecipeReference field's value.
func (s *DescribeJobOutput) SetRecipeReference(v *RecipeReference) *DescribeJobOutput {
	s.RecipeReference = v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *DescribeJobOutput) SetResourceArn(v string) *DescribeJobOutput {
	s.ResourceArn = &v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *DescribeJobOutput) SetRoleArn(v string) *DescribeJobOutput {
	s.RoleArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *DescribeJobOutput) SetTags(v map[string]*string) *DescribeJobOutput {
	s.Tags = v
	return s
}

// SetTimeout sets the Timeout field's value.
func (s *DescribeJobOutput) SetTimeout(v int64) *DescribeJobOutput {
	s.Timeout = &v
	return s
}

// SetType sets the Type field's value.
func (s *DescribeJobOutput) SetType(v string) *DescribeJobOutput {
	s.Type = &v
	return s
}

type DescribeProjectInput struct {
	_ struct{} `type:"structure"`

	// The name of the project to be described.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DescribeProjectInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeProjectInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DescribeProjectInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DescribeProjectInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DescribeProjectInput) SetName(v string) *DescribeProjectInput {
	s.Name = &v
	return s
}

type DescribeProjectOutput struct {
	_ struct{} `type:"structure"`

	// The date and time that the project was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (user name) of the user who created the project.
	CreatedBy *string `type:"string"`

	// The dataset associated with the project.
	DatasetName *string `min:"1" type:"string"`

	// The identifier (user name) of the user who last modified the project.
	LastModifiedBy *string `type:"string"`

	// The date and time that the project was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The name of the project.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The date and time when the project was opened.
	OpenDate *time.Time `type:"timestamp"`

	// The identifier (user name) of the user that opened the project for use.
	OpenedBy *string `type:"string"`

	// The recipe associated with this job.
	RecipeName *string `min:"1" type:"string"`

	// The Amazon Resource Name (ARN) of the project.
	ResourceArn *string `min:"20" type:"string"`

	// The ARN of the AWS Identity and Access Management (IAM) role that was assumed
	// for this request.
	RoleArn *string `min:"20" type:"string"`

	// Represents the sample size and sampling type for AWS Glue DataBrew to use
	// for interactive data analysis.
	Sample *Sample `type:"structure"`

	// Describes the current state of the session:
	//
	//    * PROVISIONING - allocating resources for the session.
	//
	//    * INITIALIZING - getting the session ready for first use.
	//
	//    * ASSIGNED - the session is ready for use.
	SessionStatus *string `type:"string" enum:"SessionStatus"`

	// Metadata tags associated with this project.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s DescribeProjectOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeProjectOutput) GoString() string {
	return s.String()
}

// SetCreateDate sets the CreateDate field's value.
func (s *DescribeProjectOutput) SetCreateDate(v time.Time) *DescribeProjectOutput {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *DescribeProjectOutput) SetCreatedBy(v string) *DescribeProjectOutput {
	s.CreatedBy = &v
	return s
}

// SetDatasetName sets the DatasetName field's value.
func (s *DescribeProjectOutput) SetDatasetName(v string) *DescribeProjectOutput {
	s.DatasetName = &v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *DescribeProjectOutput) SetLastModifiedBy(v string) *DescribeProjectOutput {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *DescribeProjectOutput) SetLastModifiedDate(v time.Time) *DescribeProjectOutput {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *DescribeProjectOutput) SetName(v string) *DescribeProjectOutput {
	s.Name = &v
	return s
}

// SetOpenDate sets the OpenDate field's value.
func (s *DescribeProjectOutput) SetOpenDate(v time.Time) *DescribeProjectOutput {
	s.OpenDate = &v
	return s
}

// SetOpenedBy sets the OpenedBy field's value.
func (s *DescribeProjectOutput) SetOpenedBy(v string) *DescribeProjectOutput {
	s.OpenedBy = &v
	return s
}

// SetRecipeName sets the RecipeName field's value.
func (s *DescribeProjectOutput) SetRecipeName(v string) *DescribeProjectOutput {
	s.RecipeName = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *DescribeProjectOutput) SetResourceArn(v string) *DescribeProjectOutput {
	s.ResourceArn = &v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *DescribeProjectOutput) SetRoleArn(v string) *DescribeProjectOutput {
	s.RoleArn = &v
	return s
}

// SetSample sets the Sample field's value.
func (s *DescribeProjectOutput) SetSample(v *Sample) *DescribeProjectOutput {
	s.Sample = v
	return s
}

// SetSessionStatus sets the SessionStatus field's value.
func (s *DescribeProjectOutput) SetSessionStatus(v string) *DescribeProjectOutput {
	s.SessionStatus = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *DescribeProjectOutput) SetTags(v map[string]*string) *DescribeProjectOutput {
	s.Tags = v
	return s
}

type DescribeRecipeInput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe to be described.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// The recipe version identifier. If this parameter isn't specified, then the
	// latest published version is returned.
	RecipeVersion *string `location:"querystring" locationName:"recipeVersion" min:"1" type:"string"`
}

// String returns the string representation
func (s DescribeRecipeInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeRecipeInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DescribeRecipeInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DescribeRecipeInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RecipeVersion != nil && len(*s.RecipeVersion) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RecipeVersion", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DescribeRecipeInput) SetName(v string) *DescribeRecipeInput {
	s.Name = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *DescribeRecipeInput) SetRecipeVersion(v string) *DescribeRecipeInput {
	s.RecipeVersion = &v
	return s
}

type DescribeRecipeOutput struct {
	_ struct{} `type:"structure"`

	// The date and time that the recipe was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (user name) of the user who created the recipe.
	CreatedBy *string `type:"string"`

	// The description of the recipe.
	Description *string `type:"string"`

	// The identifier (user name) of the user who last modified the recipe.
	LastModifiedBy *string `type:"string"`

	// The date and time that the recipe was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The name of the recipe.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The name of the project associated with this recipe.
	ProjectName *string `min:"1" type:"string"`

	// The identifier (user name) of the user who last published the recipe.
	PublishedBy *string `type:"string"`

	// The date and time when the recipe was last published.
	PublishedDate *time.Time `type:"timestamp"`

	// The recipe version identifier.
	RecipeVersion *string `min:"1" type:"string"`

	// The ARN of the recipe.
	ResourceArn *string `min:"20" type:"string"`

	// One or more steps to be performed by the recipe. Each step consists of an
	// action, and the conditions under which the action should succeed.
	Steps []*RecipeStep `type:"list"`

	// Metadata tags associated with this project.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s DescribeRecipeOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeRecipeOutput) GoString() string {
	return s.String()
}

// SetCreateDate sets the CreateDate field's value.
func (s *DescribeRecipeOutput) SetCreateDate(v time.Time) *DescribeRecipeOutput {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *DescribeRecipeOutput) SetCreatedBy(v string) *DescribeRecipeOutput {
	s.CreatedBy = &v
	return s
}

// SetDescription sets the Description field's value.
func (s *DescribeRecipeOutput) SetDescription(v string) *DescribeRecipeOutput {
	s.Description = &v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *DescribeRecipeOutput) SetLastModifiedBy(v string) *DescribeRecipeOutput {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *DescribeRecipeOutput) SetLastModifiedDate(v time.Time) *DescribeRecipeOutput {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *DescribeRecipeOutput) SetName(v string) *DescribeRecipeOutput {
	s.Name = &v
	return s
}

// SetProjectName sets the ProjectName field's value.
func (s *DescribeRecipeOutput) SetProjectName(v string) *DescribeRecipeOutput {
	s.ProjectName = &v
	return s
}

// SetPublishedBy sets the PublishedBy field's value.
func (s *DescribeRecipeOutput) SetPublishedBy(v string) *DescribeRecipeOutput {
	s.PublishedBy = &v
	return s
}

// SetPublishedDate sets the PublishedDate field's value.
func (s *DescribeRecipeOutput) SetPublishedDate(v time.Time) *DescribeRecipeOutput {
	s.PublishedDate = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *DescribeRecipeOutput) SetRecipeVersion(v string) *DescribeRecipeOutput {
	s.RecipeVersion = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *DescribeRecipeOutput) SetResourceArn(v string) *DescribeRecipeOutput {
	s.ResourceArn = &v
	return s
}

// SetSteps sets the Steps field's value.
func (s *DescribeRecipeOutput) SetSteps(v []*RecipeStep) *DescribeRecipeOutput {
	s.Steps = v
	return s
}

// SetTags sets the Tags field's value.
func (s *DescribeRecipeOutput) SetTags(v map[string]*string) *DescribeRecipeOutput {
	s.Tags = v
	return s
}

type DescribeScheduleInput struct {
	_ struct{} `type:"structure"`

	// The name of the schedule to be described.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s DescribeScheduleInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeScheduleInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *DescribeScheduleInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "DescribeScheduleInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *DescribeScheduleInput) SetName(v string) *DescribeScheduleInput {
	s.Name = &v
	return s
}

type DescribeScheduleOutput struct {
	_ struct{} `type:"structure"`

	// The date and time that the schedule was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (user name) of the user who created the schedule.
	CreatedBy *string `type:"string"`

	// The date or dates and time or times, in cron format, when the jobs are to
	// be run for the schedule.
	CronExpression *string `min:"1" type:"string"`

	// The name or names of one or more jobs to be run by using the schedule.
	JobNames []*string `type:"list"`

	// The identifier (user name) of the user who last modified the schedule.
	LastModifiedBy *string `type:"string"`

	// The date and time that the schedule was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The name of the schedule.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) of the schedule.
	ResourceArn *string `min:"20" type:"string"`

	// Metadata tags associated with this schedule.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s DescribeScheduleOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s DescribeScheduleOutput) GoString() string {
	return s.String()
}

// SetCreateDate sets the CreateDate field's value.
func (s *DescribeScheduleOutput) SetCreateDate(v time.Time) *DescribeScheduleOutput {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *DescribeScheduleOutput) SetCreatedBy(v string) *DescribeScheduleOutput {
	s.CreatedBy = &v
	return s
}

// SetCronExpression sets the CronExpression field's value.
func (s *DescribeScheduleOutput) SetCronExpression(v string) *DescribeScheduleOutput {
	s.CronExpression = &v
	return s
}

// SetJobNames sets the JobNames field's value.
func (s *DescribeScheduleOutput) SetJobNames(v []*string) *DescribeScheduleOutput {
	s.JobNames = v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *DescribeScheduleOutput) SetLastModifiedBy(v string) *DescribeScheduleOutput {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *DescribeScheduleOutput) SetLastModifiedDate(v time.Time) *DescribeScheduleOutput {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *DescribeScheduleOutput) SetName(v string) *DescribeScheduleOutput {
	s.Name = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *DescribeScheduleOutput) SetResourceArn(v string) *DescribeScheduleOutput {
	s.ResourceArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *DescribeScheduleOutput) SetTags(v map[string]*string) *DescribeScheduleOutput {
	s.Tags = v
	return s
}

// Options that define how DataBrew will interpret a Microsoft Excel file, when
// creating a dataset from that file.
type ExcelOptions struct {
	_ struct{} `type:"structure"`

	// Specifies one or more sheet numbers in the Excel file, which will be included
	// in the dataset.
	SheetIndexes []*int64 `min:"1" type:"list"`

	// Specifies one or more named sheets in the Excel file, which will be included
	// in the dataset.
	SheetNames []*string `min:"1" type:"list"`
}

// String returns the string representation
func (s ExcelOptions) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ExcelOptions) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ExcelOptions) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ExcelOptions"}
	if s.SheetIndexes != nil && len(s.SheetIndexes) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("SheetIndexes", 1))
	}
	if s.SheetNames != nil && len(s.SheetNames) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("SheetNames", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetSheetIndexes sets the SheetIndexes field's value.
func (s *ExcelOptions) SetSheetIndexes(v []*int64) *ExcelOptions {
	s.SheetIndexes = v
	return s
}

// SetSheetNames sets the SheetNames field's value.
func (s *ExcelOptions) SetSheetNames(v []*string) *ExcelOptions {
	s.SheetNames = v
	return s
}

// Options that define how Microsoft Excel input is to be interpreted by DataBrew.
type FormatOptions struct {
	_ struct{} `type:"structure"`

	// Options that define how Excel input is to be interpreted by DataBrew.
	Excel *ExcelOptions `type:"structure"`

	// Options that define how JSON input is to be interpreted by DataBrew.
	Json *JsonOptions `type:"structure"`
}

// String returns the string representation
func (s FormatOptions) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s FormatOptions) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *FormatOptions) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "FormatOptions"}
	if s.Excel != nil {
		if err := s.Excel.Validate(); err != nil {
			invalidParams.AddNested("Excel", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetExcel sets the Excel field's value.
func (s *FormatOptions) SetExcel(v *ExcelOptions) *FormatOptions {
	s.Excel = v
	return s
}

// SetJson sets the Json field's value.
func (s *FormatOptions) SetJson(v *JsonOptions) *FormatOptions {
	s.Json = v
	return s
}

// Information on how AWS Glue DataBrew can find data, in either the AWS Glue
// Data Catalog or Amazon S3.
type Input struct {
	_ struct{} `type:"structure"`

	// The AWS Glue Data Catalog parameters for the data.
	DataCatalogInputDefinition *DataCatalogInputDefinition `type:"structure"`

	// The Amazon S3 location where the data is stored.
	S3InputDefinition *S3Location `type:"structure"`
}

// String returns the string representation
func (s Input) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Input) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *Input) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "Input"}
	if s.DataCatalogInputDefinition != nil {
		if err := s.DataCatalogInputDefinition.Validate(); err != nil {
			invalidParams.AddNested("DataCatalogInputDefinition", err.(request.ErrInvalidParams))
		}
	}
	if s.S3InputDefinition != nil {
		if err := s.S3InputDefinition.Validate(); err != nil {
			invalidParams.AddNested("S3InputDefinition", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDataCatalogInputDefinition sets the DataCatalogInputDefinition field's value.
func (s *Input) SetDataCatalogInputDefinition(v *DataCatalogInputDefinition) *Input {
	s.DataCatalogInputDefinition = v
	return s
}

// SetS3InputDefinition sets the S3InputDefinition field's value.
func (s *Input) SetS3InputDefinition(v *S3Location) *Input {
	s.S3InputDefinition = v
	return s
}

// An internal service failure occurred.
type InternalServerException struct {
	_            struct{}                  `type:"structure"`
	RespMetadata protocol.ResponseMetadata `json:"-" xml:"-"`

	Message_ *string `locationName:"Message" type:"string"`
}

// String returns the string representation
func (s InternalServerException) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s InternalServerException) GoString() string {
	return s.String()
}

func newErrorInternalServerException(v protocol.ResponseMetadata) error {
	return &InternalServerException{
		RespMetadata: v,
	}
}

// Code returns the exception type name.
func (s *InternalServerException) Code() string {
	return "InternalServerException"
}

// Message returns the exception's message.
func (s *InternalServerException) Message() string {
	if s.Message_ != nil {
		return *s.Message_
	}
	return ""
}

// OrigErr always returns nil, satisfies awserr.Error interface.
func (s *InternalServerException) OrigErr() error {
	return nil
}

func (s *InternalServerException) Error() string {
	return fmt.Sprintf("%s: %s", s.Code(), s.Message())
}

// Status code returns the HTTP status code for the request's response error.
func (s *InternalServerException) StatusCode() int {
	return s.RespMetadata.StatusCode
}

// RequestID returns the service's response RequestID for request.
func (s *InternalServerException) RequestID() string {
	return s.RespMetadata.RequestID
}

// Represents all of the attributes of an AWS Glue DataBrew job.
type Job struct {
	_ struct{} `type:"structure"`

	// The ID of the AWS account that owns the job.
	AccountId *string `type:"string"`

	// The date and time that the job was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (the user name) of the user who created the job.
	CreatedBy *string `type:"string"`

	// A dataset that the job is to process.
	DatasetName *string `min:"1" type:"string"`

	// The Amazon Resource Name (ARN) of an encryption key that is used to protect
	// a job.
	EncryptionKeyArn *string `min:"20" type:"string"`

	// The encryption mode for the job, which can be one of the following:
	//
	//    * SSE-KMS - Server-side encryption with AWS KMS-managed keys.
	//
	//    * SSE-S3 - Server-side encryption with keys managed by Amazon S3.
	EncryptionMode *string `type:"string" enum:"EncryptionMode"`

	// The identifier (the user name) of the user who last modified the job.
	LastModifiedBy *string `type:"string"`

	// The modification date and time of the job.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The current status of Amazon CloudWatch logging for the job.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// The maximum number of nodes that can be consumed when the job processes data.
	MaxCapacity *int64 `type:"integer"`

	// The maximum number of times to retry the job after a job run fails.
	MaxRetries *int64 `type:"integer"`

	// The unique name of the job.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// One or more artifacts that represent output from running the job.
	Outputs []*Output `min:"1" type:"list"`

	// The name of the project that the job is associated with.
	ProjectName *string `min:"1" type:"string"`

	// A set of steps that the job runs.
	RecipeReference *RecipeReference `type:"structure"`

	// The unique Amazon Resource Name (ARN) for the job.
	ResourceArn *string `min:"20" type:"string"`

	// The Amazon Resource Name (ARN) of the role that will be assumed for this
	// job.
	RoleArn *string `min:"20" type:"string"`

	// Metadata tags that have been applied to the job.
	Tags map[string]*string `min:"1" type:"map"`

	// The job's timeout in minutes. A job that attempts to run longer than this
	// timeout period ends with a status of TIMEOUT.
	Timeout *int64 `type:"integer"`

	// The job type of the job, which must be one of the following:
	//
	//    * PROFILE - A job to analyze a dataset, to determine its size, data types,
	//    data distribution, and more.
	//
	//    * RECIPE - A job to apply one or more transformations to a dataset.
	Type *string `type:"string" enum:"JobType"`
}

// String returns the string representation
func (s Job) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Job) GoString() string {
	return s.String()
}

// SetAccountId sets the AccountId field's value.
func (s *Job) SetAccountId(v string) *Job {
	s.AccountId = &v
	return s
}

// SetCreateDate sets the CreateDate field's value.
func (s *Job) SetCreateDate(v time.Time) *Job {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *Job) SetCreatedBy(v string) *Job {
	s.CreatedBy = &v
	return s
}

// SetDatasetName sets the DatasetName field's value.
func (s *Job) SetDatasetName(v string) *Job {
	s.DatasetName = &v
	return s
}

// SetEncryptionKeyArn sets the EncryptionKeyArn field's value.
func (s *Job) SetEncryptionKeyArn(v string) *Job {
	s.EncryptionKeyArn = &v
	return s
}

// SetEncryptionMode sets the EncryptionMode field's value.
func (s *Job) SetEncryptionMode(v string) *Job {
	s.EncryptionMode = &v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *Job) SetLastModifiedBy(v string) *Job {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *Job) SetLastModifiedDate(v time.Time) *Job {
	s.LastModifiedDate = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *Job) SetLogSubscription(v string) *Job {
	s.LogSubscription = &v
	return s
}

// SetMaxCapacity sets the MaxCapacity field's value.
func (s *Job) SetMaxCapacity(v int64) *Job {
	s.MaxCapacity = &v
	return s
}

// SetMaxRetries sets the MaxRetries field's value.
func (s *Job) SetMaxRetries(v int64) *Job {
	s.MaxRetries = &v
	return s
}

// SetName sets the Name field's value.
func (s *Job) SetName(v string) *Job {
	s.Name = &v
	return s
}

// SetOutputs sets the Outputs field's value.
func (s *Job) SetOutputs(v []*Output) *Job {
	s.Outputs = v
	return s
}

// SetProjectName sets the ProjectName field's value.
func (s *Job) SetProjectName(v string) *Job {
	s.ProjectName = &v
	return s
}

// SetRecipeReference sets the RecipeReference field's value.
func (s *Job) SetRecipeReference(v *RecipeReference) *Job {
	s.RecipeReference = v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *Job) SetResourceArn(v string) *Job {
	s.ResourceArn = &v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *Job) SetRoleArn(v string) *Job {
	s.RoleArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *Job) SetTags(v map[string]*string) *Job {
	s.Tags = v
	return s
}

// SetTimeout sets the Timeout field's value.
func (s *Job) SetTimeout(v int64) *Job {
	s.Timeout = &v
	return s
}

// SetType sets the Type field's value.
func (s *Job) SetType(v string) *Job {
	s.Type = &v
	return s
}

// Represents one run of an AWS Glue DataBrew job.
type JobRun struct {
	_ struct{} `type:"structure"`

	// The number of times that DataBrew has attempted to run the job.
	Attempt *int64 `type:"integer"`

	// The date and time when the job completed processing.
	CompletedOn *time.Time `type:"timestamp"`

	// The name of the dataset for the job to process.
	DatasetName *string `min:"1" type:"string"`

	// A message indicating an error (if any) that was encountered when the job
	// ran.
	ErrorMessage *string `type:"string"`

	// The amount of time, in seconds, during which a job run consumed resources.
	ExecutionTime *int64 `type:"integer"`

	// The name of the job being processed during this run.
	JobName *string `min:"1" type:"string"`

	// The name of an Amazon CloudWatch log group, where the job writes diagnostic
	// messages when it runs.
	LogGroupName *string `min:"1" type:"string"`

	// The current status of Amazon CloudWatch logging for the job run.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// One or more output artifacts from a job run.
	Outputs []*Output `min:"1" type:"list"`

	// The set of steps processed by the job.
	RecipeReference *RecipeReference `type:"structure"`

	// The unique identifier of the job run.
	RunId *string `min:"1" type:"string"`

	// The identifier (the user name) of the user who initiated the job run.
	StartedBy *string `type:"string"`

	// The date and time when the job run began.
	StartedOn *time.Time `type:"timestamp"`

	// The current state of the job run entity itself.
	State *string `type:"string" enum:"JobRunState"`
}

// String returns the string representation
func (s JobRun) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s JobRun) GoString() string {
	return s.String()
}

// SetAttempt sets the Attempt field's value.
func (s *JobRun) SetAttempt(v int64) *JobRun {
	s.Attempt = &v
	return s
}

// SetCompletedOn sets the CompletedOn field's value.
func (s *JobRun) SetCompletedOn(v time.Time) *JobRun {
	s.CompletedOn = &v
	return s
}

// SetDatasetName sets the DatasetName field's value.
func (s *JobRun) SetDatasetName(v string) *JobRun {
	s.DatasetName = &v
	return s
}

// SetErrorMessage sets the ErrorMessage field's value.
func (s *JobRun) SetErrorMessage(v string) *JobRun {
	s.ErrorMessage = &v
	return s
}

// SetExecutionTime sets the ExecutionTime field's value.
func (s *JobRun) SetExecutionTime(v int64) *JobRun {
	s.ExecutionTime = &v
	return s
}

// SetJobName sets the JobName field's value.
func (s *JobRun) SetJobName(v string) *JobRun {
	s.JobName = &v
	return s
}

// SetLogGroupName sets the LogGroupName field's value.
func (s *JobRun) SetLogGroupName(v string) *JobRun {
	s.LogGroupName = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *JobRun) SetLogSubscription(v string) *JobRun {
	s.LogSubscription = &v
	return s
}

// SetOutputs sets the Outputs field's value.
func (s *JobRun) SetOutputs(v []*Output) *JobRun {
	s.Outputs = v
	return s
}

// SetRecipeReference sets the RecipeReference field's value.
func (s *JobRun) SetRecipeReference(v *RecipeReference) *JobRun {
	s.RecipeReference = v
	return s
}

// SetRunId sets the RunId field's value.
func (s *JobRun) SetRunId(v string) *JobRun {
	s.RunId = &v
	return s
}

// SetStartedBy sets the StartedBy field's value.
func (s *JobRun) SetStartedBy(v string) *JobRun {
	s.StartedBy = &v
	return s
}

// SetStartedOn sets the StartedOn field's value.
func (s *JobRun) SetStartedOn(v time.Time) *JobRun {
	s.StartedOn = &v
	return s
}

// SetState sets the State field's value.
func (s *JobRun) SetState(v string) *JobRun {
	s.State = &v
	return s
}

// Represents the JSON-specific options that define how input is to be interpreted
// by AWS Glue DataBrew.
type JsonOptions struct {
	_ struct{} `type:"structure"`

	// A value that specifies whether JSON input contains embedded new line characters.
	MultiLine *bool `type:"boolean"`
}

// String returns the string representation
func (s JsonOptions) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s JsonOptions) GoString() string {
	return s.String()
}

// SetMultiLine sets the MultiLine field's value.
func (s *JsonOptions) SetMultiLine(v bool) *JsonOptions {
	s.MultiLine = &v
	return s
}

type ListDatasetsInput struct {
	_ struct{} `type:"structure"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`
}

// String returns the string representation
func (s ListDatasetsInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListDatasetsInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListDatasetsInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListDatasetsInput"}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListDatasetsInput) SetMaxResults(v int64) *ListDatasetsInput {
	s.MaxResults = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListDatasetsInput) SetNextToken(v string) *ListDatasetsInput {
	s.NextToken = &v
	return s
}

type ListDatasetsOutput struct {
	_ struct{} `type:"structure"`

	// A list of datasets that are defined in the current AWS account.
	//
	// Datasets is a required field
	Datasets []*Dataset `type:"list" required:"true"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To obtain the next set of pages, pass
	// in the NextToken from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`
}

// String returns the string representation
func (s ListDatasetsOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListDatasetsOutput) GoString() string {
	return s.String()
}

// SetDatasets sets the Datasets field's value.
func (s *ListDatasetsOutput) SetDatasets(v []*Dataset) *ListDatasetsOutput {
	s.Datasets = v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListDatasetsOutput) SetNextToken(v string) *ListDatasetsOutput {
	s.NextToken = &v
	return s
}

type ListJobRunsInput struct {
	_ struct{} `type:"structure"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// The name of the job.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// A token generated by AWS Glue DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`
}

// String returns the string representation
func (s ListJobRunsInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListJobRunsInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListJobRunsInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListJobRunsInput"}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListJobRunsInput) SetMaxResults(v int64) *ListJobRunsInput {
	s.MaxResults = &v
	return s
}

// SetName sets the Name field's value.
func (s *ListJobRunsInput) SetName(v string) *ListJobRunsInput {
	s.Name = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListJobRunsInput) SetNextToken(v string) *ListJobRunsInput {
	s.NextToken = &v
	return s
}

type ListJobRunsOutput struct {
	_ struct{} `type:"structure"`

	// A list of job runs that have occurred for the specified job.
	//
	// JobRuns is a required field
	JobRuns []*JobRun `type:"list" required:"true"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To obtain the next set of pages, pass
	// in the NextToken from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`
}

// String returns the string representation
func (s ListJobRunsOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListJobRunsOutput) GoString() string {
	return s.String()
}

// SetJobRuns sets the JobRuns field's value.
func (s *ListJobRunsOutput) SetJobRuns(v []*JobRun) *ListJobRunsOutput {
	s.JobRuns = v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListJobRunsOutput) SetNextToken(v string) *ListJobRunsOutput {
	s.NextToken = &v
	return s
}

type ListJobsInput struct {
	_ struct{} `type:"structure"`

	// The name of a dataset. Using this parameter indicates to return only those
	// jobs that act on the specified dataset.
	DatasetName *string `location:"querystring" locationName:"datasetName" min:"1" type:"string"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`

	// The name of a project. Using this parameter indicates to return only those
	// jobs that are associated with the specified project.
	ProjectName *string `location:"querystring" locationName:"projectName" min:"1" type:"string"`
}

// String returns the string representation
func (s ListJobsInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListJobsInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListJobsInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListJobsInput"}
	if s.DatasetName != nil && len(*s.DatasetName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("DatasetName", 1))
	}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}
	if s.ProjectName != nil && len(*s.ProjectName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("ProjectName", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDatasetName sets the DatasetName field's value.
func (s *ListJobsInput) SetDatasetName(v string) *ListJobsInput {
	s.DatasetName = &v
	return s
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListJobsInput) SetMaxResults(v int64) *ListJobsInput {
	s.MaxResults = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListJobsInput) SetNextToken(v string) *ListJobsInput {
	s.NextToken = &v
	return s
}

// SetProjectName sets the ProjectName field's value.
func (s *ListJobsInput) SetProjectName(v string) *ListJobsInput {
	s.ProjectName = &v
	return s
}

type ListJobsOutput struct {
	_ struct{} `type:"structure"`

	// A list of jobs that are defined in the current AWS account.
	//
	// Jobs is a required field
	Jobs []*Job `type:"list" required:"true"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To obtain the next set of pages, pass
	// in the NextToken from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`
}

// String returns the string representation
func (s ListJobsOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListJobsOutput) GoString() string {
	return s.String()
}

// SetJobs sets the Jobs field's value.
func (s *ListJobsOutput) SetJobs(v []*Job) *ListJobsOutput {
	s.Jobs = v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListJobsOutput) SetNextToken(v string) *ListJobsOutput {
	s.NextToken = &v
	return s
}

type ListProjectsInput struct {
	_ struct{} `type:"structure"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// A pagination token that can be used in a subsequent request.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`
}

// String returns the string representation
func (s ListProjectsInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListProjectsInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListProjectsInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListProjectsInput"}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListProjectsInput) SetMaxResults(v int64) *ListProjectsInput {
	s.MaxResults = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListProjectsInput) SetNextToken(v string) *ListProjectsInput {
	s.NextToken = &v
	return s
}

type ListProjectsOutput struct {
	_ struct{} `type:"structure"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`

	// A list of projects that are defined in the current AWS account.
	//
	// Projects is a required field
	Projects []*Project `type:"list" required:"true"`
}

// String returns the string representation
func (s ListProjectsOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListProjectsOutput) GoString() string {
	return s.String()
}

// SetNextToken sets the NextToken field's value.
func (s *ListProjectsOutput) SetNextToken(v string) *ListProjectsOutput {
	s.NextToken = &v
	return s
}

// SetProjects sets the Projects field's value.
func (s *ListProjectsOutput) SetProjects(v []*Project) *ListProjectsOutput {
	s.Projects = v
	return s
}

type ListRecipeVersionsInput struct {
	_ struct{} `type:"structure"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// The name of the recipe for which to return version information.
	//
	// Name is a required field
	Name *string `location:"querystring" locationName:"name" min:"1" type:"string" required:"true"`

	// A pagination token that can be used in a subsequent request.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`
}

// String returns the string representation
func (s ListRecipeVersionsInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListRecipeVersionsInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListRecipeVersionsInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListRecipeVersionsInput"}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListRecipeVersionsInput) SetMaxResults(v int64) *ListRecipeVersionsInput {
	s.MaxResults = &v
	return s
}

// SetName sets the Name field's value.
func (s *ListRecipeVersionsInput) SetName(v string) *ListRecipeVersionsInput {
	s.Name = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListRecipeVersionsInput) SetNextToken(v string) *ListRecipeVersionsInput {
	s.NextToken = &v
	return s
}

type ListRecipeVersionsOutput struct {
	_ struct{} `type:"structure"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`

	// A list of versions for the specified recipe.
	//
	// Recipes is a required field
	Recipes []*Recipe `type:"list" required:"true"`
}

// String returns the string representation
func (s ListRecipeVersionsOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListRecipeVersionsOutput) GoString() string {
	return s.String()
}

// SetNextToken sets the NextToken field's value.
func (s *ListRecipeVersionsOutput) SetNextToken(v string) *ListRecipeVersionsOutput {
	s.NextToken = &v
	return s
}

// SetRecipes sets the Recipes field's value.
func (s *ListRecipeVersionsOutput) SetRecipes(v []*Recipe) *ListRecipeVersionsOutput {
	s.Recipes = v
	return s
}

type ListRecipesInput struct {
	_ struct{} `type:"structure"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// A pagination token that can be used in a subsequent request.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`

	// A version identifier. Using this parameter indicates to return only those
	// recipes that have this version identifier.
	RecipeVersion *string `location:"querystring" locationName:"recipeVersion" min:"1" type:"string"`
}

// String returns the string representation
func (s ListRecipesInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListRecipesInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListRecipesInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListRecipesInput"}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}
	if s.RecipeVersion != nil && len(*s.RecipeVersion) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RecipeVersion", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListRecipesInput) SetMaxResults(v int64) *ListRecipesInput {
	s.MaxResults = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListRecipesInput) SetNextToken(v string) *ListRecipesInput {
	s.NextToken = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *ListRecipesInput) SetRecipeVersion(v string) *ListRecipesInput {
	s.RecipeVersion = &v
	return s
}

type ListRecipesOutput struct {
	_ struct{} `type:"structure"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`

	// A list of recipes that are defined in the current AWS account.
	//
	// Recipes is a required field
	Recipes []*Recipe `type:"list" required:"true"`
}

// String returns the string representation
func (s ListRecipesOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListRecipesOutput) GoString() string {
	return s.String()
}

// SetNextToken sets the NextToken field's value.
func (s *ListRecipesOutput) SetNextToken(v string) *ListRecipesOutput {
	s.NextToken = &v
	return s
}

// SetRecipes sets the Recipes field's value.
func (s *ListRecipesOutput) SetRecipes(v []*Recipe) *ListRecipesOutput {
	s.Recipes = v
	return s
}

type ListSchedulesInput struct {
	_ struct{} `type:"structure"`

	// The name of the job that these schedules apply to.
	JobName *string `location:"querystring" locationName:"jobName" min:"1" type:"string"`

	// The maximum number of results to return in this request.
	MaxResults *int64 `location:"querystring" locationName:"maxResults" min:"1" type:"integer"`

	// A pagination token that can be used in a subsequent request.
	NextToken *string `location:"querystring" locationName:"nextToken" min:"1" type:"string"`
}

// String returns the string representation
func (s ListSchedulesInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListSchedulesInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListSchedulesInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListSchedulesInput"}
	if s.JobName != nil && len(*s.JobName) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("JobName", 1))
	}
	if s.MaxResults != nil && *s.MaxResults < 1 {
		invalidParams.Add(request.NewErrParamMinValue("MaxResults", 1))
	}
	if s.NextToken != nil && len(*s.NextToken) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("NextToken", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetJobName sets the JobName field's value.
func (s *ListSchedulesInput) SetJobName(v string) *ListSchedulesInput {
	s.JobName = &v
	return s
}

// SetMaxResults sets the MaxResults field's value.
func (s *ListSchedulesInput) SetMaxResults(v int64) *ListSchedulesInput {
	s.MaxResults = &v
	return s
}

// SetNextToken sets the NextToken field's value.
func (s *ListSchedulesInput) SetNextToken(v string) *ListSchedulesInput {
	s.NextToken = &v
	return s
}

type ListSchedulesOutput struct {
	_ struct{} `type:"structure"`

	// A token generated by DataBrew that specifies where to continue pagination
	// if a previous request was truncated. To get the next set of pages, pass in
	// the NextToken value from the response object of the previous page call.
	NextToken *string `min:"1" type:"string"`

	// A list of schedules in the current AWS account.
	//
	// Schedules is a required field
	Schedules []*Schedule `type:"list" required:"true"`
}

// String returns the string representation
func (s ListSchedulesOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListSchedulesOutput) GoString() string {
	return s.String()
}

// SetNextToken sets the NextToken field's value.
func (s *ListSchedulesOutput) SetNextToken(v string) *ListSchedulesOutput {
	s.NextToken = &v
	return s
}

// SetSchedules sets the Schedules field's value.
func (s *ListSchedulesOutput) SetSchedules(v []*Schedule) *ListSchedulesOutput {
	s.Schedules = v
	return s
}

type ListTagsForResourceInput struct {
	_ struct{} `type:"structure"`

	// The Amazon Resource Name (ARN) string that uniquely identifies the DataBrew
	// resource.
	//
	// ResourceArn is a required field
	ResourceArn *string `location:"uri" locationName:"ResourceArn" min:"20" type:"string" required:"true"`
}

// String returns the string representation
func (s ListTagsForResourceInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListTagsForResourceInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ListTagsForResourceInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ListTagsForResourceInput"}
	if s.ResourceArn == nil {
		invalidParams.Add(request.NewErrParamRequired("ResourceArn"))
	}
	if s.ResourceArn != nil && len(*s.ResourceArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("ResourceArn", 20))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetResourceArn sets the ResourceArn field's value.
func (s *ListTagsForResourceInput) SetResourceArn(v string) *ListTagsForResourceInput {
	s.ResourceArn = &v
	return s
}

type ListTagsForResourceOutput struct {
	_ struct{} `type:"structure"`

	// A list of tags associated with the DataBrew resource.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s ListTagsForResourceOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ListTagsForResourceOutput) GoString() string {
	return s.String()
}

// SetTags sets the Tags field's value.
func (s *ListTagsForResourceOutput) SetTags(v map[string]*string) *ListTagsForResourceOutput {
	s.Tags = v
	return s
}

// Represents individual output from a particular job run.
type Output struct {
	_ struct{} `type:"structure"`

	// The compression algorithm used to compress the output text of the job.
	CompressionFormat *string `type:"string" enum:"CompressionFormat"`

	// The data format of the output of the job.
	Format *string `type:"string" enum:"OutputFormat"`

	// The location in Amazon S3 where the job writes its output.
	//
	// Location is a required field
	Location *S3Location `type:"structure" required:"true"`

	// A value that, if true, means that any data in the location specified for
	// output is overwritten with new output.
	Overwrite *bool `type:"boolean"`

	// The names of one or more partition columns for the output of the job.
	PartitionColumns []*string `type:"list"`
}

// String returns the string representation
func (s Output) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Output) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *Output) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "Output"}
	if s.Location == nil {
		invalidParams.Add(request.NewErrParamRequired("Location"))
	}
	if s.Location != nil {
		if err := s.Location.Validate(); err != nil {
			invalidParams.AddNested("Location", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetCompressionFormat sets the CompressionFormat field's value.
func (s *Output) SetCompressionFormat(v string) *Output {
	s.CompressionFormat = &v
	return s
}

// SetFormat sets the Format field's value.
func (s *Output) SetFormat(v string) *Output {
	s.Format = &v
	return s
}

// SetLocation sets the Location field's value.
func (s *Output) SetLocation(v *S3Location) *Output {
	s.Location = v
	return s
}

// SetOverwrite sets the Overwrite field's value.
func (s *Output) SetOverwrite(v bool) *Output {
	s.Overwrite = &v
	return s
}

// SetPartitionColumns sets the PartitionColumns field's value.
func (s *Output) SetPartitionColumns(v []*string) *Output {
	s.PartitionColumns = v
	return s
}

// Represents all of the attributes of an AWS Glue DataBrew project.
type Project struct {
	_ struct{} `type:"structure"`

	// The ID of the AWS account that owns the project.
	AccountId *string `type:"string"`

	// The date and time that the project was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (the user name) of the user who crated the project.
	CreatedBy *string `type:"string"`

	// The dataset that the project is to act upon.
	DatasetName *string `min:"1" type:"string"`

	// The identifier (user name) of the user who last modified the project.
	LastModifiedBy *string `type:"string"`

	// The last modification date and time for the project.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The unique name of a project.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The date and time when the project was opened.
	OpenDate *time.Time `type:"timestamp"`

	// The identifier (the user name) of the user that opened the project for use.
	OpenedBy *string `type:"string"`

	// The name of a recipe that will be developed during a project session.
	//
	// RecipeName is a required field
	RecipeName *string `min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) for the project.
	ResourceArn *string `min:"20" type:"string"`

	// The Amazon Resource Name (ARN) of the role that will be assumed for this
	// project.
	RoleArn *string `min:"20" type:"string"`

	// The sample size and sampling type to apply to the data. If this parameter
	// isn't specified, then the sample will consiste of the first 500 rows from
	// the dataset.
	Sample *Sample `type:"structure"`

	// Metadata tags that have been applied to the project.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s Project) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Project) GoString() string {
	return s.String()
}

// SetAccountId sets the AccountId field's value.
func (s *Project) SetAccountId(v string) *Project {
	s.AccountId = &v
	return s
}

// SetCreateDate sets the CreateDate field's value.
func (s *Project) SetCreateDate(v time.Time) *Project {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *Project) SetCreatedBy(v string) *Project {
	s.CreatedBy = &v
	return s
}

// SetDatasetName sets the DatasetName field's value.
func (s *Project) SetDatasetName(v string) *Project {
	s.DatasetName = &v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *Project) SetLastModifiedBy(v string) *Project {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *Project) SetLastModifiedDate(v time.Time) *Project {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *Project) SetName(v string) *Project {
	s.Name = &v
	return s
}

// SetOpenDate sets the OpenDate field's value.
func (s *Project) SetOpenDate(v time.Time) *Project {
	s.OpenDate = &v
	return s
}

// SetOpenedBy sets the OpenedBy field's value.
func (s *Project) SetOpenedBy(v string) *Project {
	s.OpenedBy = &v
	return s
}

// SetRecipeName sets the RecipeName field's value.
func (s *Project) SetRecipeName(v string) *Project {
	s.RecipeName = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *Project) SetResourceArn(v string) *Project {
	s.ResourceArn = &v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *Project) SetRoleArn(v string) *Project {
	s.RoleArn = &v
	return s
}

// SetSample sets the Sample field's value.
func (s *Project) SetSample(v *Sample) *Project {
	s.Sample = v
	return s
}

// SetTags sets the Tags field's value.
func (s *Project) SetTags(v map[string]*string) *Project {
	s.Tags = v
	return s
}

type PublishRecipeInput struct {
	_ struct{} `type:"structure"`

	// A description of the recipe to be published, for this version of the recipe.
	Description *string `type:"string"`

	// The name of the recipe to be published.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s PublishRecipeInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s PublishRecipeInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *PublishRecipeInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "PublishRecipeInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDescription sets the Description field's value.
func (s *PublishRecipeInput) SetDescription(v string) *PublishRecipeInput {
	s.Description = &v
	return s
}

// SetName sets the Name field's value.
func (s *PublishRecipeInput) SetName(v string) *PublishRecipeInput {
	s.Name = &v
	return s
}

type PublishRecipeOutput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe that you published.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s PublishRecipeOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s PublishRecipeOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *PublishRecipeOutput) SetName(v string) *PublishRecipeOutput {
	s.Name = &v
	return s
}

// Represents one or more actions to be performed on an AWS Glue DataBrew dataset.
type Recipe struct {
	_ struct{} `type:"structure"`

	// The date and time that the recipe was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (the user name) of the user who created the recipe.
	CreatedBy *string `type:"string"`

	// The description of the recipe.
	Description *string `type:"string"`

	// The identifier (user name) of the user who last modified the recipe.
	LastModifiedBy *string `type:"string"`

	// The last modification date and time of the recipe.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The unique name for the recipe.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The name of the project that the recipe is associated with.
	ProjectName *string `min:"1" type:"string"`

	// The identifier (the user name) of the user who published the recipe.
	PublishedBy *string `type:"string"`

	// The date and time when the recipe was published.
	PublishedDate *time.Time `type:"timestamp"`

	// The identifier for the version for the recipe.
	RecipeVersion *string `min:"1" type:"string"`

	// The Amazon Resource Name (ARN) for the recipe.
	ResourceArn *string `min:"20" type:"string"`

	// A list of steps that are defined by the recipe.
	Steps []*RecipeStep `type:"list"`

	// Metadata tags that have been applied to the recipe.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s Recipe) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Recipe) GoString() string {
	return s.String()
}

// SetCreateDate sets the CreateDate field's value.
func (s *Recipe) SetCreateDate(v time.Time) *Recipe {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *Recipe) SetCreatedBy(v string) *Recipe {
	s.CreatedBy = &v
	return s
}

// SetDescription sets the Description field's value.
func (s *Recipe) SetDescription(v string) *Recipe {
	s.Description = &v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *Recipe) SetLastModifiedBy(v string) *Recipe {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *Recipe) SetLastModifiedDate(v time.Time) *Recipe {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *Recipe) SetName(v string) *Recipe {
	s.Name = &v
	return s
}

// SetProjectName sets the ProjectName field's value.
func (s *Recipe) SetProjectName(v string) *Recipe {
	s.ProjectName = &v
	return s
}

// SetPublishedBy sets the PublishedBy field's value.
func (s *Recipe) SetPublishedBy(v string) *Recipe {
	s.PublishedBy = &v
	return s
}

// SetPublishedDate sets the PublishedDate field's value.
func (s *Recipe) SetPublishedDate(v time.Time) *Recipe {
	s.PublishedDate = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *Recipe) SetRecipeVersion(v string) *Recipe {
	s.RecipeVersion = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *Recipe) SetResourceArn(v string) *Recipe {
	s.ResourceArn = &v
	return s
}

// SetSteps sets the Steps field's value.
func (s *Recipe) SetSteps(v []*RecipeStep) *Recipe {
	s.Steps = v
	return s
}

// SetTags sets the Tags field's value.
func (s *Recipe) SetTags(v map[string]*string) *Recipe {
	s.Tags = v
	return s
}

// Represents a transformation and associated parameters that are used to apply
// a change to an AWS Glue DataBrew dataset. For more information, see Recipe
// structure (https://docs.aws.amazon.com/databrew/latest/dg/recipe-structure.html)
// and ecipe actions reference (https://docs.aws.amazon.com/databrew/latest/dg/recipe-actions-reference.html) .
type RecipeAction struct {
	_ struct{} `type:"structure"`

	// The name of a valid DataBrew transformation to be performed on the data.
	//
	// Operation is a required field
	Operation *string `min:"1" type:"string" required:"true"`

	// Contextual parameters for the transformation.
	Parameters map[string]*string `type:"map"`
}

// String returns the string representation
func (s RecipeAction) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s RecipeAction) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *RecipeAction) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "RecipeAction"}
	if s.Operation == nil {
		invalidParams.Add(request.NewErrParamRequired("Operation"))
	}
	if s.Operation != nil && len(*s.Operation) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Operation", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetOperation sets the Operation field's value.
func (s *RecipeAction) SetOperation(v string) *RecipeAction {
	s.Operation = &v
	return s
}

// SetParameters sets the Parameters field's value.
func (s *RecipeAction) SetParameters(v map[string]*string) *RecipeAction {
	s.Parameters = v
	return s
}

// Represents all of the attributes of an AWS Glue DataBrew recipe.
type RecipeReference struct {
	_ struct{} `type:"structure"`

	// The name of the recipe.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The identifier for the version for the recipe.
	RecipeVersion *string `min:"1" type:"string"`
}

// String returns the string representation
func (s RecipeReference) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s RecipeReference) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *RecipeReference) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "RecipeReference"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RecipeVersion != nil && len(*s.RecipeVersion) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RecipeVersion", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *RecipeReference) SetName(v string) *RecipeReference {
	s.Name = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *RecipeReference) SetRecipeVersion(v string) *RecipeReference {
	s.RecipeVersion = &v
	return s
}

// Represents a single step to be performed in an AWS Glue DataBrew recipe.
type RecipeStep struct {
	_ struct{} `type:"structure"`

	// The particular action to be performed in the recipe step.
	//
	// Action is a required field
	Action *RecipeAction `type:"structure" required:"true"`

	// One or more conditions that must be met, in order for the recipe step to
	// succeed.
	//
	// All of the conditions in the array must be met. In other words, all of the
	// conditions must be combined using a logical AND operation.
	ConditionExpressions []*ConditionExpression `type:"list"`
}

// String returns the string representation
func (s RecipeStep) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s RecipeStep) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *RecipeStep) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "RecipeStep"}
	if s.Action == nil {
		invalidParams.Add(request.NewErrParamRequired("Action"))
	}
	if s.Action != nil {
		if err := s.Action.Validate(); err != nil {
			invalidParams.AddNested("Action", err.(request.ErrInvalidParams))
		}
	}
	if s.ConditionExpressions != nil {
		for i, v := range s.ConditionExpressions {
			if v == nil {
				continue
			}
			if err := v.Validate(); err != nil {
				invalidParams.AddNested(fmt.Sprintf("%s[%v]", "ConditionExpressions", i), err.(request.ErrInvalidParams))
			}
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetAction sets the Action field's value.
func (s *RecipeStep) SetAction(v *RecipeAction) *RecipeStep {
	s.Action = v
	return s
}

// SetConditionExpressions sets the ConditionExpressions field's value.
func (s *RecipeStep) SetConditionExpressions(v []*ConditionExpression) *RecipeStep {
	s.ConditionExpressions = v
	return s
}

// Represents any errors encountered when attempting to delete multiple recipe
// versions.
type RecipeVersionErrorDetail struct {
	_ struct{} `type:"structure"`

	// The HTTP status code for the error.
	ErrorCode *string `type:"string"`

	// The text of the error message.
	ErrorMessage *string `type:"string"`

	// The identifier for the recipe version associated with this error.
	RecipeVersion *string `min:"1" type:"string"`
}

// String returns the string representation
func (s RecipeVersionErrorDetail) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s RecipeVersionErrorDetail) GoString() string {
	return s.String()
}

// SetErrorCode sets the ErrorCode field's value.
func (s *RecipeVersionErrorDetail) SetErrorCode(v string) *RecipeVersionErrorDetail {
	s.ErrorCode = &v
	return s
}

// SetErrorMessage sets the ErrorMessage field's value.
func (s *RecipeVersionErrorDetail) SetErrorMessage(v string) *RecipeVersionErrorDetail {
	s.ErrorMessage = &v
	return s
}

// SetRecipeVersion sets the RecipeVersion field's value.
func (s *RecipeVersionErrorDetail) SetRecipeVersion(v string) *RecipeVersionErrorDetail {
	s.RecipeVersion = &v
	return s
}

// One or more resources can't be found.
type ResourceNotFoundException struct {
	_            struct{}                  `type:"structure"`
	RespMetadata protocol.ResponseMetadata `json:"-" xml:"-"`

	Message_ *string `locationName:"Message" type:"string"`
}

// String returns the string representation
func (s ResourceNotFoundException) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ResourceNotFoundException) GoString() string {
	return s.String()
}

func newErrorResourceNotFoundException(v protocol.ResponseMetadata) error {
	return &ResourceNotFoundException{
		RespMetadata: v,
	}
}

// Code returns the exception type name.
func (s *ResourceNotFoundException) Code() string {
	return "ResourceNotFoundException"
}

// Message returns the exception's message.
func (s *ResourceNotFoundException) Message() string {
	if s.Message_ != nil {
		return *s.Message_
	}
	return ""
}

// OrigErr always returns nil, satisfies awserr.Error interface.
func (s *ResourceNotFoundException) OrigErr() error {
	return nil
}

func (s *ResourceNotFoundException) Error() string {
	return fmt.Sprintf("%s: %s", s.Code(), s.Message())
}

// Status code returns the HTTP status code for the request's response error.
func (s *ResourceNotFoundException) StatusCode() int {
	return s.RespMetadata.StatusCode
}

// RequestID returns the service's response RequestID for request.
func (s *ResourceNotFoundException) RequestID() string {
	return s.RespMetadata.RequestID
}

// An Amazon S3 location (bucket name an object key) where DataBrew can read
// input data, or write output from a job.
type S3Location struct {
	_ struct{} `type:"structure"`

	// The S3 bucket name.
	//
	// Bucket is a required field
	Bucket *string `min:"3" type:"string" required:"true"`

	// The unique name of the object in the bucket.
	Key *string `min:"1" type:"string"`
}

// String returns the string representation
func (s S3Location) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s S3Location) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *S3Location) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "S3Location"}
	if s.Bucket == nil {
		invalidParams.Add(request.NewErrParamRequired("Bucket"))
	}
	if s.Bucket != nil && len(*s.Bucket) < 3 {
		invalidParams.Add(request.NewErrParamMinLen("Bucket", 3))
	}
	if s.Key != nil && len(*s.Key) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Key", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetBucket sets the Bucket field's value.
func (s *S3Location) SetBucket(v string) *S3Location {
	s.Bucket = &v
	return s
}

// SetKey sets the Key field's value.
func (s *S3Location) SetKey(v string) *S3Location {
	s.Key = &v
	return s
}

// Represents the sample size and sampling type for AWS Glue DataBrew to use
// for interactive data analysis.
type Sample struct {
	_ struct{} `type:"structure"`

	// The number of rows in the sample.
	Size *int64 `min:"1" type:"integer"`

	// The way in which DataBrew obtains rows from a dataset.
	//
	// Type is a required field
	Type *string `type:"string" required:"true" enum:"SampleType"`
}

// String returns the string representation
func (s Sample) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Sample) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *Sample) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "Sample"}
	if s.Size != nil && *s.Size < 1 {
		invalidParams.Add(request.NewErrParamMinValue("Size", 1))
	}
	if s.Type == nil {
		invalidParams.Add(request.NewErrParamRequired("Type"))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetSize sets the Size field's value.
func (s *Sample) SetSize(v int64) *Sample {
	s.Size = &v
	return s
}

// SetType sets the Type field's value.
func (s *Sample) SetType(v string) *Sample {
	s.Type = &v
	return s
}

// Represents one or more dates and times when a job is to run.
type Schedule struct {
	_ struct{} `type:"structure"`

	// The ID of the AWS account that owns the schedule.
	AccountId *string `type:"string"`

	// The date and time that the schedule was created.
	CreateDate *time.Time `type:"timestamp"`

	// The identifier (the user name) of the user who created the schedule.
	CreatedBy *string `type:"string"`

	// The date(s) and time(s), in cron format, when the job will run.
	CronExpression *string `min:"1" type:"string"`

	// A list of jobs to be run, according to the schedule.
	JobNames []*string `type:"list"`

	// The identifier (the user name) of the user who last modified the schedule.
	LastModifiedBy *string `type:"string"`

	// The date and time when the schedule was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The name of the schedule.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) of the schedule.
	ResourceArn *string `min:"20" type:"string"`

	// Metadata tags that have been applied to the schedule.
	Tags map[string]*string `min:"1" type:"map"`
}

// String returns the string representation
func (s Schedule) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s Schedule) GoString() string {
	return s.String()
}

// SetAccountId sets the AccountId field's value.
func (s *Schedule) SetAccountId(v string) *Schedule {
	s.AccountId = &v
	return s
}

// SetCreateDate sets the CreateDate field's value.
func (s *Schedule) SetCreateDate(v time.Time) *Schedule {
	s.CreateDate = &v
	return s
}

// SetCreatedBy sets the CreatedBy field's value.
func (s *Schedule) SetCreatedBy(v string) *Schedule {
	s.CreatedBy = &v
	return s
}

// SetCronExpression sets the CronExpression field's value.
func (s *Schedule) SetCronExpression(v string) *Schedule {
	s.CronExpression = &v
	return s
}

// SetJobNames sets the JobNames field's value.
func (s *Schedule) SetJobNames(v []*string) *Schedule {
	s.JobNames = v
	return s
}

// SetLastModifiedBy sets the LastModifiedBy field's value.
func (s *Schedule) SetLastModifiedBy(v string) *Schedule {
	s.LastModifiedBy = &v
	return s
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *Schedule) SetLastModifiedDate(v time.Time) *Schedule {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *Schedule) SetName(v string) *Schedule {
	s.Name = &v
	return s
}

// SetResourceArn sets the ResourceArn field's value.
func (s *Schedule) SetResourceArn(v string) *Schedule {
	s.ResourceArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *Schedule) SetTags(v map[string]*string) *Schedule {
	s.Tags = v
	return s
}

type SendProjectSessionActionInput struct {
	_ struct{} `type:"structure"`

	// A unique identifier for an interactive session that's currently open and
	// ready for work. The action will be performed on this session.
	ClientSessionId *string `min:"1" type:"string"`

	// The name of the project to apply the action to.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// Returns the result of the recipe step, without applying it. The result isn't
	// added to the view frame stack.
	Preview *bool `type:"boolean"`

	// Represents a single step to be performed in an AWS Glue DataBrew recipe.
	RecipeStep *RecipeStep `type:"structure"`

	// The index from which to preview a step. This index is used to preview the
	// result of steps that have already been applied, so that the resulting view
	// frame is from earlier in the view frame stack.
	StepIndex *int64 `type:"integer"`

	// Represents the data being being transformed during an AWS Glue DataBrew project
	// session.
	ViewFrame *ViewFrame `type:"structure"`
}

// String returns the string representation
func (s SendProjectSessionActionInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s SendProjectSessionActionInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *SendProjectSessionActionInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "SendProjectSessionActionInput"}
	if s.ClientSessionId != nil && len(*s.ClientSessionId) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("ClientSessionId", 1))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RecipeStep != nil {
		if err := s.RecipeStep.Validate(); err != nil {
			invalidParams.AddNested("RecipeStep", err.(request.ErrInvalidParams))
		}
	}
	if s.ViewFrame != nil {
		if err := s.ViewFrame.Validate(); err != nil {
			invalidParams.AddNested("ViewFrame", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetClientSessionId sets the ClientSessionId field's value.
func (s *SendProjectSessionActionInput) SetClientSessionId(v string) *SendProjectSessionActionInput {
	s.ClientSessionId = &v
	return s
}

// SetName sets the Name field's value.
func (s *SendProjectSessionActionInput) SetName(v string) *SendProjectSessionActionInput {
	s.Name = &v
	return s
}

// SetPreview sets the Preview field's value.
func (s *SendProjectSessionActionInput) SetPreview(v bool) *SendProjectSessionActionInput {
	s.Preview = &v
	return s
}

// SetRecipeStep sets the RecipeStep field's value.
func (s *SendProjectSessionActionInput) SetRecipeStep(v *RecipeStep) *SendProjectSessionActionInput {
	s.RecipeStep = v
	return s
}

// SetStepIndex sets the StepIndex field's value.
func (s *SendProjectSessionActionInput) SetStepIndex(v int64) *SendProjectSessionActionInput {
	s.StepIndex = &v
	return s
}

// SetViewFrame sets the ViewFrame field's value.
func (s *SendProjectSessionActionInput) SetViewFrame(v *ViewFrame) *SendProjectSessionActionInput {
	s.ViewFrame = v
	return s
}

type SendProjectSessionActionOutput struct {
	_ struct{} `type:"structure"`

	// A unique identifier for the action that was performed.
	ActionId *int64 `type:"integer"`

	// The name of the project that was affected by the action.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`

	// A message indicating the result of performing the action.
	Result *string `type:"string"`
}

// String returns the string representation
func (s SendProjectSessionActionOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s SendProjectSessionActionOutput) GoString() string {
	return s.String()
}

// SetActionId sets the ActionId field's value.
func (s *SendProjectSessionActionOutput) SetActionId(v int64) *SendProjectSessionActionOutput {
	s.ActionId = &v
	return s
}

// SetName sets the Name field's value.
func (s *SendProjectSessionActionOutput) SetName(v string) *SendProjectSessionActionOutput {
	s.Name = &v
	return s
}

// SetResult sets the Result field's value.
func (s *SendProjectSessionActionOutput) SetResult(v string) *SendProjectSessionActionOutput {
	s.Result = &v
	return s
}

// A service quota is exceeded.
type ServiceQuotaExceededException struct {
	_            struct{}                  `type:"structure"`
	RespMetadata protocol.ResponseMetadata `json:"-" xml:"-"`

	Message_ *string `locationName:"Message" type:"string"`
}

// String returns the string representation
func (s ServiceQuotaExceededException) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ServiceQuotaExceededException) GoString() string {
	return s.String()
}

func newErrorServiceQuotaExceededException(v protocol.ResponseMetadata) error {
	return &ServiceQuotaExceededException{
		RespMetadata: v,
	}
}

// Code returns the exception type name.
func (s *ServiceQuotaExceededException) Code() string {
	return "ServiceQuotaExceededException"
}

// Message returns the exception's message.
func (s *ServiceQuotaExceededException) Message() string {
	if s.Message_ != nil {
		return *s.Message_
	}
	return ""
}

// OrigErr always returns nil, satisfies awserr.Error interface.
func (s *ServiceQuotaExceededException) OrigErr() error {
	return nil
}

func (s *ServiceQuotaExceededException) Error() string {
	return fmt.Sprintf("%s: %s", s.Code(), s.Message())
}

// Status code returns the HTTP status code for the request's response error.
func (s *ServiceQuotaExceededException) StatusCode() int {
	return s.RespMetadata.StatusCode
}

// RequestID returns the service's response RequestID for request.
func (s *ServiceQuotaExceededException) RequestID() string {
	return s.RespMetadata.RequestID
}

type StartJobRunInput struct {
	_ struct{} `type:"structure"`

	// The name of the job to be run.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s StartJobRunInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s StartJobRunInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *StartJobRunInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "StartJobRunInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *StartJobRunInput) SetName(v string) *StartJobRunInput {
	s.Name = &v
	return s
}

type StartJobRunOutput struct {
	_ struct{} `type:"structure"`

	// A system-generated identifier for this particular job run.
	//
	// RunId is a required field
	RunId *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s StartJobRunOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s StartJobRunOutput) GoString() string {
	return s.String()
}

// SetRunId sets the RunId field's value.
func (s *StartJobRunOutput) SetRunId(v string) *StartJobRunOutput {
	s.RunId = &v
	return s
}

type StartProjectSessionInput struct {
	_ struct{} `type:"structure"`

	// A value that, if true, enables you to take control of a session, even if
	// a different client is currently accessing the project.
	AssumeControl *bool `type:"boolean"`

	// The name of the project to act upon.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s StartProjectSessionInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s StartProjectSessionInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *StartProjectSessionInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "StartProjectSessionInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetAssumeControl sets the AssumeControl field's value.
func (s *StartProjectSessionInput) SetAssumeControl(v bool) *StartProjectSessionInput {
	s.AssumeControl = &v
	return s
}

// SetName sets the Name field's value.
func (s *StartProjectSessionInput) SetName(v string) *StartProjectSessionInput {
	s.Name = &v
	return s
}

type StartProjectSessionOutput struct {
	_ struct{} `type:"structure"`

	// A system-generated identifier for the session.
	ClientSessionId *string `min:"1" type:"string"`

	// The name of the project to be acted upon.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s StartProjectSessionOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s StartProjectSessionOutput) GoString() string {
	return s.String()
}

// SetClientSessionId sets the ClientSessionId field's value.
func (s *StartProjectSessionOutput) SetClientSessionId(v string) *StartProjectSessionOutput {
	s.ClientSessionId = &v
	return s
}

// SetName sets the Name field's value.
func (s *StartProjectSessionOutput) SetName(v string) *StartProjectSessionOutput {
	s.Name = &v
	return s
}

type StopJobRunInput struct {
	_ struct{} `type:"structure"`

	// The name of the job to be stopped.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// The ID of the job run to be stopped.
	//
	// RunId is a required field
	RunId *string `location:"uri" locationName:"runId" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s StopJobRunInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s StopJobRunInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *StopJobRunInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "StopJobRunInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RunId == nil {
		invalidParams.Add(request.NewErrParamRequired("RunId"))
	}
	if s.RunId != nil && len(*s.RunId) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("RunId", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *StopJobRunInput) SetName(v string) *StopJobRunInput {
	s.Name = &v
	return s
}

// SetRunId sets the RunId field's value.
func (s *StopJobRunInput) SetRunId(v string) *StopJobRunInput {
	s.RunId = &v
	return s
}

type StopJobRunOutput struct {
	_ struct{} `type:"structure"`

	// The ID of the job run that you stopped.
	//
	// RunId is a required field
	RunId *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s StopJobRunOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s StopJobRunOutput) GoString() string {
	return s.String()
}

// SetRunId sets the RunId field's value.
func (s *StopJobRunOutput) SetRunId(v string) *StopJobRunOutput {
	s.RunId = &v
	return s
}

type TagResourceInput struct {
	_ struct{} `type:"structure"`

	// The DataBrew resource to which tags should be added. The value for this parameter
	// is an Amazon Resource Name (ARN). For DataBrew, you can tag a dataset, a
	// job, a project, or a recipe.
	//
	// ResourceArn is a required field
	ResourceArn *string `location:"uri" locationName:"ResourceArn" min:"20" type:"string" required:"true"`

	// One or more tags to be assigned to the resource.
	//
	// Tags is a required field
	Tags map[string]*string `min:"1" type:"map" required:"true"`
}

// String returns the string representation
func (s TagResourceInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s TagResourceInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *TagResourceInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "TagResourceInput"}
	if s.ResourceArn == nil {
		invalidParams.Add(request.NewErrParamRequired("ResourceArn"))
	}
	if s.ResourceArn != nil && len(*s.ResourceArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("ResourceArn", 20))
	}
	if s.Tags == nil {
		invalidParams.Add(request.NewErrParamRequired("Tags"))
	}
	if s.Tags != nil && len(s.Tags) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Tags", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetResourceArn sets the ResourceArn field's value.
func (s *TagResourceInput) SetResourceArn(v string) *TagResourceInput {
	s.ResourceArn = &v
	return s
}

// SetTags sets the Tags field's value.
func (s *TagResourceInput) SetTags(v map[string]*string) *TagResourceInput {
	s.Tags = v
	return s
}

type TagResourceOutput struct {
	_ struct{} `type:"structure"`
}

// String returns the string representation
func (s TagResourceOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s TagResourceOutput) GoString() string {
	return s.String()
}

type UntagResourceInput struct {
	_ struct{} `type:"structure"`

	// An DataBrew resource from which you want to remove a tag or tags. The value
	// for this parameter is an Amazon Resource Name (ARN).
	//
	// ResourceArn is a required field
	ResourceArn *string `location:"uri" locationName:"ResourceArn" min:"20" type:"string" required:"true"`

	// The tag keys (names) of one or more tags to be removed.
	//
	// TagKeys is a required field
	TagKeys []*string `location:"querystring" locationName:"tagKeys" min:"1" type:"list" required:"true"`
}

// String returns the string representation
func (s UntagResourceInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UntagResourceInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UntagResourceInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UntagResourceInput"}
	if s.ResourceArn == nil {
		invalidParams.Add(request.NewErrParamRequired("ResourceArn"))
	}
	if s.ResourceArn != nil && len(*s.ResourceArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("ResourceArn", 20))
	}
	if s.TagKeys == nil {
		invalidParams.Add(request.NewErrParamRequired("TagKeys"))
	}
	if s.TagKeys != nil && len(s.TagKeys) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("TagKeys", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetResourceArn sets the ResourceArn field's value.
func (s *UntagResourceInput) SetResourceArn(v string) *UntagResourceInput {
	s.ResourceArn = &v
	return s
}

// SetTagKeys sets the TagKeys field's value.
func (s *UntagResourceInput) SetTagKeys(v []*string) *UntagResourceInput {
	s.TagKeys = v
	return s
}

type UntagResourceOutput struct {
	_ struct{} `type:"structure"`
}

// String returns the string representation
func (s UntagResourceOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UntagResourceOutput) GoString() string {
	return s.String()
}

type UpdateDatasetInput struct {
	_ struct{} `type:"structure"`

	// Options that define how Microsoft Excel input is to be interpreted by DataBrew.
	FormatOptions *FormatOptions `type:"structure"`

	// Information on how AWS Glue DataBrew can find data, in either the AWS Glue
	// Data Catalog or Amazon S3.
	//
	// Input is a required field
	Input *Input `type:"structure" required:"true"`

	// The name of the dataset to be updated.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateDatasetInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateDatasetInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UpdateDatasetInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UpdateDatasetInput"}
	if s.Input == nil {
		invalidParams.Add(request.NewErrParamRequired("Input"))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.FormatOptions != nil {
		if err := s.FormatOptions.Validate(); err != nil {
			invalidParams.AddNested("FormatOptions", err.(request.ErrInvalidParams))
		}
	}
	if s.Input != nil {
		if err := s.Input.Validate(); err != nil {
			invalidParams.AddNested("Input", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetFormatOptions sets the FormatOptions field's value.
func (s *UpdateDatasetInput) SetFormatOptions(v *FormatOptions) *UpdateDatasetInput {
	s.FormatOptions = v
	return s
}

// SetInput sets the Input field's value.
func (s *UpdateDatasetInput) SetInput(v *Input) *UpdateDatasetInput {
	s.Input = v
	return s
}

// SetName sets the Name field's value.
func (s *UpdateDatasetInput) SetName(v string) *UpdateDatasetInput {
	s.Name = &v
	return s
}

type UpdateDatasetOutput struct {
	_ struct{} `type:"structure"`

	// The name of the dataset that you updated.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateDatasetOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateDatasetOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *UpdateDatasetOutput) SetName(v string) *UpdateDatasetOutput {
	s.Name = &v
	return s
}

type UpdateProfileJobInput struct {
	_ struct{} `type:"structure"`

	// The Amazon Resource Name (ARN) of an encryption key that is used to protect
	// the job.
	EncryptionKeyArn *string `min:"20" type:"string"`

	// The encryption mode for the job, which can be one of the following:
	//
	//    * SSE-KMS - Server-side encryption with AWS KMS-managed keys.
	//
	//    * SSE-S3 - Server-side encryption with keys managed by Amazon S3.
	EncryptionMode *string `type:"string" enum:"EncryptionMode"`

	// A value that enables or disables Amazon CloudWatch logging for the current
	// AWS account. If logging is enabled, CloudWatch writes one log stream for
	// each job run.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// The maximum number of nodes that DataBrew can use when the job processes
	// data.
	MaxCapacity *int64 `type:"integer"`

	// The maximum number of times to retry the job after a job run fails.
	MaxRetries *int64 `type:"integer"`

	// The name of the job to be updated.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// An Amazon S3 location (bucket name an object key) where DataBrew can read
	// input data, or write output from a job.
	//
	// OutputLocation is a required field
	OutputLocation *S3Location `type:"structure" required:"true"`

	// The Amazon Resource Name (ARN) of the AWS Identity and Access Management
	// (IAM) role to be assumed for this request.
	//
	// RoleArn is a required field
	RoleArn *string `min:"20" type:"string" required:"true"`

	// The job's timeout in minutes. A job that attempts to run longer than this
	// timeout period ends with a status of TIMEOUT.
	Timeout *int64 `type:"integer"`
}

// String returns the string representation
func (s UpdateProfileJobInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateProfileJobInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UpdateProfileJobInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UpdateProfileJobInput"}
	if s.EncryptionKeyArn != nil && len(*s.EncryptionKeyArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("EncryptionKeyArn", 20))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.OutputLocation == nil {
		invalidParams.Add(request.NewErrParamRequired("OutputLocation"))
	}
	if s.RoleArn == nil {
		invalidParams.Add(request.NewErrParamRequired("RoleArn"))
	}
	if s.RoleArn != nil && len(*s.RoleArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("RoleArn", 20))
	}
	if s.OutputLocation != nil {
		if err := s.OutputLocation.Validate(); err != nil {
			invalidParams.AddNested("OutputLocation", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetEncryptionKeyArn sets the EncryptionKeyArn field's value.
func (s *UpdateProfileJobInput) SetEncryptionKeyArn(v string) *UpdateProfileJobInput {
	s.EncryptionKeyArn = &v
	return s
}

// SetEncryptionMode sets the EncryptionMode field's value.
func (s *UpdateProfileJobInput) SetEncryptionMode(v string) *UpdateProfileJobInput {
	s.EncryptionMode = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *UpdateProfileJobInput) SetLogSubscription(v string) *UpdateProfileJobInput {
	s.LogSubscription = &v
	return s
}

// SetMaxCapacity sets the MaxCapacity field's value.
func (s *UpdateProfileJobInput) SetMaxCapacity(v int64) *UpdateProfileJobInput {
	s.MaxCapacity = &v
	return s
}

// SetMaxRetries sets the MaxRetries field's value.
func (s *UpdateProfileJobInput) SetMaxRetries(v int64) *UpdateProfileJobInput {
	s.MaxRetries = &v
	return s
}

// SetName sets the Name field's value.
func (s *UpdateProfileJobInput) SetName(v string) *UpdateProfileJobInput {
	s.Name = &v
	return s
}

// SetOutputLocation sets the OutputLocation field's value.
func (s *UpdateProfileJobInput) SetOutputLocation(v *S3Location) *UpdateProfileJobInput {
	s.OutputLocation = v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *UpdateProfileJobInput) SetRoleArn(v string) *UpdateProfileJobInput {
	s.RoleArn = &v
	return s
}

// SetTimeout sets the Timeout field's value.
func (s *UpdateProfileJobInput) SetTimeout(v int64) *UpdateProfileJobInput {
	s.Timeout = &v
	return s
}

type UpdateProfileJobOutput struct {
	_ struct{} `type:"structure"`

	// The name of the job that was updated.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateProfileJobOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateProfileJobOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *UpdateProfileJobOutput) SetName(v string) *UpdateProfileJobOutput {
	s.Name = &v
	return s
}

type UpdateProjectInput struct {
	_ struct{} `type:"structure"`

	// The name of the project to be updated.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// The Amazon Resource Name (ARN) of the IAM role to be assumed for this request.
	//
	// RoleArn is a required field
	RoleArn *string `min:"20" type:"string" required:"true"`

	// Represents the sample size and sampling type for AWS Glue DataBrew to use
	// for interactive data analysis.
	Sample *Sample `type:"structure"`
}

// String returns the string representation
func (s UpdateProjectInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateProjectInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UpdateProjectInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UpdateProjectInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.RoleArn == nil {
		invalidParams.Add(request.NewErrParamRequired("RoleArn"))
	}
	if s.RoleArn != nil && len(*s.RoleArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("RoleArn", 20))
	}
	if s.Sample != nil {
		if err := s.Sample.Validate(); err != nil {
			invalidParams.AddNested("Sample", err.(request.ErrInvalidParams))
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetName sets the Name field's value.
func (s *UpdateProjectInput) SetName(v string) *UpdateProjectInput {
	s.Name = &v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *UpdateProjectInput) SetRoleArn(v string) *UpdateProjectInput {
	s.RoleArn = &v
	return s
}

// SetSample sets the Sample field's value.
func (s *UpdateProjectInput) SetSample(v *Sample) *UpdateProjectInput {
	s.Sample = v
	return s
}

type UpdateProjectOutput struct {
	_ struct{} `type:"structure"`

	// The date and time that the project was last modified.
	LastModifiedDate *time.Time `type:"timestamp"`

	// The name of the project that you updated.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateProjectOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateProjectOutput) GoString() string {
	return s.String()
}

// SetLastModifiedDate sets the LastModifiedDate field's value.
func (s *UpdateProjectOutput) SetLastModifiedDate(v time.Time) *UpdateProjectOutput {
	s.LastModifiedDate = &v
	return s
}

// SetName sets the Name field's value.
func (s *UpdateProjectOutput) SetName(v string) *UpdateProjectOutput {
	s.Name = &v
	return s
}

type UpdateRecipeInput struct {
	_ struct{} `type:"structure"`

	// A description of the recipe.
	Description *string `type:"string"`

	// The name of the recipe to be updated.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// One or more steps to be performed by the recipe. Each step consists of an
	// action, and the conditions under which the action should succeed.
	Steps []*RecipeStep `type:"list"`
}

// String returns the string representation
func (s UpdateRecipeInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateRecipeInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UpdateRecipeInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UpdateRecipeInput"}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.Steps != nil {
		for i, v := range s.Steps {
			if v == nil {
				continue
			}
			if err := v.Validate(); err != nil {
				invalidParams.AddNested(fmt.Sprintf("%s[%v]", "Steps", i), err.(request.ErrInvalidParams))
			}
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetDescription sets the Description field's value.
func (s *UpdateRecipeInput) SetDescription(v string) *UpdateRecipeInput {
	s.Description = &v
	return s
}

// SetName sets the Name field's value.
func (s *UpdateRecipeInput) SetName(v string) *UpdateRecipeInput {
	s.Name = &v
	return s
}

// SetSteps sets the Steps field's value.
func (s *UpdateRecipeInput) SetSteps(v []*RecipeStep) *UpdateRecipeInput {
	s.Steps = v
	return s
}

type UpdateRecipeJobInput struct {
	_ struct{} `type:"structure"`

	// The Amazon Resource Name (ARN) of an encryption key that is used to protect
	// the job.
	EncryptionKeyArn *string `min:"20" type:"string"`

	// The encryption mode for the job, which can be one of the following:
	//
	//    * SSE-KMS - Server-side encryption with AWS KMS-managed keys.
	//
	//    * SSE-S3 - Server-side encryption with keys managed by Amazon S3.
	EncryptionMode *string `type:"string" enum:"EncryptionMode"`

	// A value that enables or disables Amazon CloudWatch logging for the current
	// AWS account. If logging is enabled, CloudWatch writes one log stream for
	// each job run.
	LogSubscription *string `type:"string" enum:"LogSubscription"`

	// The maximum number of nodes that DataBrew can consume when the job processes
	// data.
	MaxCapacity *int64 `type:"integer"`

	// The maximum number of times to retry the job after a job run fails.
	MaxRetries *int64 `type:"integer"`

	// The name of the job to update.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`

	// One or more artifacts that represent the output from running the job.
	//
	// Outputs is a required field
	Outputs []*Output `min:"1" type:"list" required:"true"`

	// The Amazon Resource Name (ARN) of the AWS Identity and Access Management
	// (IAM) role to be assumed for this request.
	//
	// RoleArn is a required field
	RoleArn *string `min:"20" type:"string" required:"true"`

	// The job's timeout in minutes. A job that attempts to run longer than this
	// timeout period ends with a status of TIMEOUT.
	Timeout *int64 `type:"integer"`
}

// String returns the string representation
func (s UpdateRecipeJobInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateRecipeJobInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UpdateRecipeJobInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UpdateRecipeJobInput"}
	if s.EncryptionKeyArn != nil && len(*s.EncryptionKeyArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("EncryptionKeyArn", 20))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}
	if s.Outputs == nil {
		invalidParams.Add(request.NewErrParamRequired("Outputs"))
	}
	if s.Outputs != nil && len(s.Outputs) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Outputs", 1))
	}
	if s.RoleArn == nil {
		invalidParams.Add(request.NewErrParamRequired("RoleArn"))
	}
	if s.RoleArn != nil && len(*s.RoleArn) < 20 {
		invalidParams.Add(request.NewErrParamMinLen("RoleArn", 20))
	}
	if s.Outputs != nil {
		for i, v := range s.Outputs {
			if v == nil {
				continue
			}
			if err := v.Validate(); err != nil {
				invalidParams.AddNested(fmt.Sprintf("%s[%v]", "Outputs", i), err.(request.ErrInvalidParams))
			}
		}
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetEncryptionKeyArn sets the EncryptionKeyArn field's value.
func (s *UpdateRecipeJobInput) SetEncryptionKeyArn(v string) *UpdateRecipeJobInput {
	s.EncryptionKeyArn = &v
	return s
}

// SetEncryptionMode sets the EncryptionMode field's value.
func (s *UpdateRecipeJobInput) SetEncryptionMode(v string) *UpdateRecipeJobInput {
	s.EncryptionMode = &v
	return s
}

// SetLogSubscription sets the LogSubscription field's value.
func (s *UpdateRecipeJobInput) SetLogSubscription(v string) *UpdateRecipeJobInput {
	s.LogSubscription = &v
	return s
}

// SetMaxCapacity sets the MaxCapacity field's value.
func (s *UpdateRecipeJobInput) SetMaxCapacity(v int64) *UpdateRecipeJobInput {
	s.MaxCapacity = &v
	return s
}

// SetMaxRetries sets the MaxRetries field's value.
func (s *UpdateRecipeJobInput) SetMaxRetries(v int64) *UpdateRecipeJobInput {
	s.MaxRetries = &v
	return s
}

// SetName sets the Name field's value.
func (s *UpdateRecipeJobInput) SetName(v string) *UpdateRecipeJobInput {
	s.Name = &v
	return s
}

// SetOutputs sets the Outputs field's value.
func (s *UpdateRecipeJobInput) SetOutputs(v []*Output) *UpdateRecipeJobInput {
	s.Outputs = v
	return s
}

// SetRoleArn sets the RoleArn field's value.
func (s *UpdateRecipeJobInput) SetRoleArn(v string) *UpdateRecipeJobInput {
	s.RoleArn = &v
	return s
}

// SetTimeout sets the Timeout field's value.
func (s *UpdateRecipeJobInput) SetTimeout(v int64) *UpdateRecipeJobInput {
	s.Timeout = &v
	return s
}

type UpdateRecipeJobOutput struct {
	_ struct{} `type:"structure"`

	// The name of the job that you updated.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateRecipeJobOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateRecipeJobOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *UpdateRecipeJobOutput) SetName(v string) *UpdateRecipeJobOutput {
	s.Name = &v
	return s
}

type UpdateRecipeOutput struct {
	_ struct{} `type:"structure"`

	// The name of the recipe that was updated.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateRecipeOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateRecipeOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *UpdateRecipeOutput) SetName(v string) *UpdateRecipeOutput {
	s.Name = &v
	return s
}

type UpdateScheduleInput struct {
	_ struct{} `type:"structure"`

	// The date or dates and time or times, in cron format, when the jobs are to
	// be run.
	//
	// CronExpression is a required field
	CronExpression *string `min:"1" type:"string" required:"true"`

	// The name or names of one or more jobs to be run for this schedule.
	JobNames []*string `type:"list"`

	// The name of the schedule to update.
	//
	// Name is a required field
	Name *string `location:"uri" locationName:"name" min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateScheduleInput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateScheduleInput) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *UpdateScheduleInput) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "UpdateScheduleInput"}
	if s.CronExpression == nil {
		invalidParams.Add(request.NewErrParamRequired("CronExpression"))
	}
	if s.CronExpression != nil && len(*s.CronExpression) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("CronExpression", 1))
	}
	if s.Name == nil {
		invalidParams.Add(request.NewErrParamRequired("Name"))
	}
	if s.Name != nil && len(*s.Name) < 1 {
		invalidParams.Add(request.NewErrParamMinLen("Name", 1))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetCronExpression sets the CronExpression field's value.
func (s *UpdateScheduleInput) SetCronExpression(v string) *UpdateScheduleInput {
	s.CronExpression = &v
	return s
}

// SetJobNames sets the JobNames field's value.
func (s *UpdateScheduleInput) SetJobNames(v []*string) *UpdateScheduleInput {
	s.JobNames = v
	return s
}

// SetName sets the Name field's value.
func (s *UpdateScheduleInput) SetName(v string) *UpdateScheduleInput {
	s.Name = &v
	return s
}

type UpdateScheduleOutput struct {
	_ struct{} `type:"structure"`

	// The name of the schedule that was updated.
	//
	// Name is a required field
	Name *string `min:"1" type:"string" required:"true"`
}

// String returns the string representation
func (s UpdateScheduleOutput) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s UpdateScheduleOutput) GoString() string {
	return s.String()
}

// SetName sets the Name field's value.
func (s *UpdateScheduleOutput) SetName(v string) *UpdateScheduleOutput {
	s.Name = &v
	return s
}

// The input parameters for this request failed validation.
type ValidationException struct {
	_            struct{}                  `type:"structure"`
	RespMetadata protocol.ResponseMetadata `json:"-" xml:"-"`

	Message_ *string `locationName:"Message" type:"string"`
}

// String returns the string representation
func (s ValidationException) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ValidationException) GoString() string {
	return s.String()
}

func newErrorValidationException(v protocol.ResponseMetadata) error {
	return &ValidationException{
		RespMetadata: v,
	}
}

// Code returns the exception type name.
func (s *ValidationException) Code() string {
	return "ValidationException"
}

// Message returns the exception's message.
func (s *ValidationException) Message() string {
	if s.Message_ != nil {
		return *s.Message_
	}
	return ""
}

// OrigErr always returns nil, satisfies awserr.Error interface.
func (s *ValidationException) OrigErr() error {
	return nil
}

func (s *ValidationException) Error() string {
	return fmt.Sprintf("%s: %s", s.Code(), s.Message())
}

// Status code returns the HTTP status code for the request's response error.
func (s *ValidationException) StatusCode() int {
	return s.RespMetadata.StatusCode
}

// RequestID returns the service's response RequestID for request.
func (s *ValidationException) RequestID() string {
	return s.RespMetadata.RequestID
}

// Represents the data being being transformed during an AWS Glue DataBrew project
// session.
type ViewFrame struct {
	_ struct{} `type:"structure"`

	// The number of columns to include in the view frame, beginning with the StartColumnIndex
	// value and ignoring any columns in the HiddenColumns list.
	ColumnRange *int64 `type:"integer"`

	// A list of columns to hide in the view frame.
	HiddenColumns []*string `type:"list"`

	// The starting index for the range of columns to return in the view frame.
	//
	// StartColumnIndex is a required field
	StartColumnIndex *int64 `type:"integer" required:"true"`
}

// String returns the string representation
func (s ViewFrame) String() string {
	return awsutil.Prettify(s)
}

// GoString returns the string representation
func (s ViewFrame) GoString() string {
	return s.String()
}

// Validate inspects the fields of the type to determine if they are valid.
func (s *ViewFrame) Validate() error {
	invalidParams := request.ErrInvalidParams{Context: "ViewFrame"}
	if s.StartColumnIndex == nil {
		invalidParams.Add(request.NewErrParamRequired("StartColumnIndex"))
	}

	if invalidParams.Len() > 0 {
		return invalidParams
	}
	return nil
}

// SetColumnRange sets the ColumnRange field's value.
func (s *ViewFrame) SetColumnRange(v int64) *ViewFrame {
	s.ColumnRange = &v
	return s
}

// SetHiddenColumns sets the HiddenColumns field's value.
func (s *ViewFrame) SetHiddenColumns(v []*string) *ViewFrame {
	s.HiddenColumns = v
	return s
}

// SetStartColumnIndex sets the StartColumnIndex field's value.
func (s *ViewFrame) SetStartColumnIndex(v int64) *ViewFrame {
	s.StartColumnIndex = &v
	return s
}

const (
	// CompressionFormatGzip is a CompressionFormat enum value
	CompressionFormatGzip = "GZIP"

	// CompressionFormatLz4 is a CompressionFormat enum value
	CompressionFormatLz4 = "LZ4"

	// CompressionFormatSnappy is a CompressionFormat enum value
	CompressionFormatSnappy = "SNAPPY"

	// CompressionFormatBzip2 is a CompressionFormat enum value
	CompressionFormatBzip2 = "BZIP2"

	// CompressionFormatDeflate is a CompressionFormat enum value
	CompressionFormatDeflate = "DEFLATE"

	// CompressionFormatLzo is a CompressionFormat enum value
	CompressionFormatLzo = "LZO"

	// CompressionFormatBrotli is a CompressionFormat enum value
	CompressionFormatBrotli = "BROTLI"

	// CompressionFormatZstd is a CompressionFormat enum value
	CompressionFormatZstd = "ZSTD"

	// CompressionFormatZlib is a CompressionFormat enum value
	CompressionFormatZlib = "ZLIB"
)

// CompressionFormat_Values returns all elements of the CompressionFormat enum
func CompressionFormat_Values() []string {
	return []string{
		CompressionFormatGzip,
		CompressionFormatLz4,
		CompressionFormatSnappy,
		CompressionFormatBzip2,
		CompressionFormatDeflate,
		CompressionFormatLzo,
		CompressionFormatBrotli,
		CompressionFormatZstd,
		CompressionFormatZlib,
	}
}

const (
	// EncryptionModeSseKms is a EncryptionMode enum value
	EncryptionModeSseKms = "SSE-KMS"

	// EncryptionModeSseS3 is a EncryptionMode enum value
	EncryptionModeSseS3 = "SSE-S3"
)

// EncryptionMode_Values returns all elements of the EncryptionMode enum
func EncryptionMode_Values() []string {
	return []string{
		EncryptionModeSseKms,
		EncryptionModeSseS3,
	}
}

const (
	// JobRunStateStarting is a JobRunState enum value
	JobRunStateStarting = "STARTING"

	// JobRunStateRunning is a JobRunState enum value
	JobRunStateRunning = "RUNNING"

	// JobRunStateStopping is a JobRunState enum value
	JobRunStateStopping = "STOPPING"

	// JobRunStateStopped is a JobRunState enum value
	JobRunStateStopped = "STOPPED"

	// JobRunStateSucceeded is a JobRunState enum value
	JobRunStateSucceeded = "SUCCEEDED"

	// JobRunStateFailed is a JobRunState enum value
	JobRunStateFailed = "FAILED"

	// JobRunStateTimeout is a JobRunState enum value
	JobRunStateTimeout = "TIMEOUT"
)

// JobRunState_Values returns all elements of the JobRunState enum
func JobRunState_Values() []string {
	return []string{
		JobRunStateStarting,
		JobRunStateRunning,
		JobRunStateStopping,
		JobRunStateStopped,
		JobRunStateSucceeded,
		JobRunStateFailed,
		JobRunStateTimeout,
	}
}

const (
	// JobTypeProfile is a JobType enum value
	JobTypeProfile = "PROFILE"

	// JobTypeRecipe is a JobType enum value
	JobTypeRecipe = "RECIPE"
)

// JobType_Values returns all elements of the JobType enum
func JobType_Values() []string {
	return []string{
		JobTypeProfile,
		JobTypeRecipe,
	}
}

const (
	// LogSubscriptionEnable is a LogSubscription enum value
	LogSubscriptionEnable = "ENABLE"

	// LogSubscriptionDisable is a LogSubscription enum value
	LogSubscriptionDisable = "DISABLE"
)

// LogSubscription_Values returns all elements of the LogSubscription enum
func LogSubscription_Values() []string {
	return []string{
		LogSubscriptionEnable,
		LogSubscriptionDisable,
	}
}

const (
	// OutputFormatCsv is a OutputFormat enum value
	OutputFormatCsv = "CSV"

	// OutputFormatJson is a OutputFormat enum value
	OutputFormatJson = "JSON"

	// OutputFormatParquet is a OutputFormat enum value
	OutputFormatParquet = "PARQUET"

	// OutputFormatGlueparquet is a OutputFormat enum value
	OutputFormatGlueparquet = "GLUEPARQUET"

	// OutputFormatAvro is a OutputFormat enum value
	OutputFormatAvro = "AVRO"

	// OutputFormatOrc is a OutputFormat enum value
	OutputFormatOrc = "ORC"

	// OutputFormatXml is a OutputFormat enum value
	OutputFormatXml = "XML"
)

// OutputFormat_Values returns all elements of the OutputFormat enum
func OutputFormat_Values() []string {
	return []string{
		OutputFormatCsv,
		OutputFormatJson,
		OutputFormatParquet,
		OutputFormatGlueparquet,
		OutputFormatAvro,
		OutputFormatOrc,
		OutputFormatXml,
	}
}

const (
	// SampleTypeFirstN is a SampleType enum value
	SampleTypeFirstN = "FIRST_N"

	// SampleTypeLastN is a SampleType enum value
	SampleTypeLastN = "LAST_N"

	// SampleTypeRandom is a SampleType enum value
	SampleTypeRandom = "RANDOM"
)

// SampleType_Values returns all elements of the SampleType enum
func SampleType_Values() []string {
	return []string{
		SampleTypeFirstN,
		SampleTypeLastN,
		SampleTypeRandom,
	}
}

const (
	// SessionStatusAssigned is a SessionStatus enum value
	SessionStatusAssigned = "ASSIGNED"

	// SessionStatusFailed is a SessionStatus enum value
	SessionStatusFailed = "FAILED"

	// SessionStatusInitializing is a SessionStatus enum value
	SessionStatusInitializing = "INITIALIZING"

	// SessionStatusProvisioning is a SessionStatus enum value
	SessionStatusProvisioning = "PROVISIONING"

	// SessionStatusReady is a SessionStatus enum value
	SessionStatusReady = "READY"

	// SessionStatusRecycling is a SessionStatus enum value
	SessionStatusRecycling = "RECYCLING"

	// SessionStatusRotating is a SessionStatus enum value
	SessionStatusRotating = "ROTATING"

	// SessionStatusTerminated is a SessionStatus enum value
	SessionStatusTerminated = "TERMINATED"

	// SessionStatusTerminating is a SessionStatus enum value
	SessionStatusTerminating = "TERMINATING"

	// SessionStatusUpdating is a SessionStatus enum value
	SessionStatusUpdating = "UPDATING"
)

// SessionStatus_Values returns all elements of the SessionStatus enum
func SessionStatus_Values() []string {
	return []string{
		SessionStatusAssigned,
		SessionStatusFailed,
		SessionStatusInitializing,
		SessionStatusProvisioning,
		SessionStatusReady,
		SessionStatusRecycling,
		SessionStatusRotating,
		SessionStatusTerminated,
		SessionStatusTerminating,
		SessionStatusUpdating,
	}
}

const (
	// SourceS3 is a Source enum value
	SourceS3 = "S3"

	// SourceDataCatalog is a Source enum value
	SourceDataCatalog = "DATA-CATALOG"
)

// Source_Values returns all elements of the Source enum
func Source_Values() []string {
	return []string{
		SourceS3,
		SourceDataCatalog,
	}
}
